import React, { forwardRef, useState, useMemo, useCallback, useRef, useEffect } from 'react';
import styled from 'styled-components';
import { isIOS, isMobile } from 'react-device-detect';
import ReactDOM from 'react-dom';
import { useCombobox } from 'downshift';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  strings.raw = raw;
  return strings;
}

var _sizes;

var neutrals = {
  black: '#222222',
  darkgray1: '',
  darkgray2: '',
  darkgray3: '#777777',
  darkgray4: '',
  gray1: '#9B9B9B',
  gray2: '#CACACA',
  gray3: '#E8E8E8',
  gray4: '#F4F4F4',
  gray5: '#F8F8F8',
  white: '#FFFFFF'
};
/**
 * Map numeric values to CSS px values
 * @param {*} v
 */

var px = function px(v) {
  return v + "px";
};
/**
 * @breakpoints
 *
 * When used with `sx` helper, 0 index means for all viewports (mobile first):
 *
 * ```
 * sx({
 *   // applies font size small to all viewport widths,
 *   // font size medium above the first breakpoint,
 *   // font size large above the next breakpoint
 *   fontSize: [ 'small', 'medium', 'large' ]
 * })
 * ```
 */


var breakpoints = ['576px', '768px', '992px', '1200px', '1400px']; // index in sx:         1,       2,       3,       4,        5  (not a mistake, 0 is smallest viewport)

/**
 * @mediaQueries
 *
 * Example:
 * @media ${theme.mediaQueries.tablet} {
 *   font-size: ${theme.fontSize.small}
 * }
 */

var mediaQueries = {
  tablet: "screen and (min-width: " + breakpoints[1] + ")",
  desktop: "screen and (min-width: " + breakpoints[2] + ")"
};
/**
 * @sizes
 */
// index:              0,  1,  2,  3,  4,  5,  6,  7,  8,   9,

var iconSizeScale = /*#__PURE__*/[16, 20, 22, 24, 32, 40, 50, 75, 100, 105].map(px);
var sizes = (_sizes = {
  vW: '100vw',
  vH: '100vh',
  quarter: '25%',
  third: '33.33%',
  half: '50%',
  twoThird: '66.66%',
  threeQuarter: '75%',
  full: '100%',
  icons: iconSizeScale
}, _sizes[1 / 4] = '25%', _sizes[1 / 3] = '33.33%', _sizes[1 / 2] = '50%', _sizes[2 / 3] = '66.66%', _sizes[3 / 4] = '75%', _sizes[1] = '100%', _sizes);
/**
 * @fonts
 */

var fonts = {
  body: '-apple-system, BlinkMacSystemFont, Open Sans, Roboto, sans-serif',
  heading: 'inherit',
  monospace: 'SFMono-Regular, Consolas, Liberation Mono, Menlo, monospace'
};
/**
 * @lineHeights
 */
// index:            0,   1,   2,   3,   4,   5

var inputHeights = {
  sm: '36px',
  md: '56px',
  xs: '176px'
};
/**
 * @fontWeights
 */

var fontWeights = {
  regular: 400,
  bold: 700,
  body: 400,
  heading: 700,
  normal: 400
};
var primarys = {
  primary50: '#ffebef',
  primary100: '#FFCDD4',
  primary200: '#F7999D',
  primary300: '#F07176',
  primary400: '#FD4C53',
  primary500: '#FF3638',
  primary600: '#F42B38',
  primary700: '#E21E30',
  primary800: '#D5132A',
  primary900: '#9E0017'
};
var secondarys = {
  secondary50: '#DDEFFD',
  secondary100: '#BBDEFB',
  secondary200: '#90CAF9',
  secondary300: '#64B5F6',
  secondary400: '#42A5F5',
  secondary500: '#2196F3',
  secondary600: '#1E88E5',
  secondary700: '#1976D2',
  secondary800: '#1565C0',
  secondary900: '#0D47A1'
};
var greens = {
  green50: '#E5F4E9',
  green100: '#C0E5C9',
  green200: '#97D3A8',
  green300: '#6BC385',
  green400: '#47B76C',
  green500: '#17AA52',
  green600: '#0a9b49',
  green700: '#00893D',
  green800: '#007832',
  green900: '#00591F'
};
var yellows = {
  yellow50: '#FFF7E1',
  yellow100: '#FEEAB4',
  yellow200: '#FEDD84',
  yellow300: '#FDD153',
  yellow400: '#FCC630',
  yellow500: '#FBBD1C',
  yellow600: '#FBAF17',
  yellow700: '#FA9D16',
  yellow800: '#FA8C15',
  yellow900: '#F86D13'
};
var grays = {
  gray50: '#FAFAFA',
  gray100: '#F5F5F5',
  gray200: '#EEEEEE',
  gray300: '#E0E0E0',
  gray400: '#BDBDBD',
  gray500: '#9E9E9E',
  gray600: '#757575',
  gray700: '#616161',
  gray800: '#424242',
  gray900: '#212121'
};
var surfaces = {
  surface1: '#ffebef',
  surface2: '#E1F6FD',
  surface3: '#E5F4E9',
  surface25: '#FFFFFF',
  surface100: '#F5F5F5',
  surface300: '#E0E0E0',
  surface500: '#9E9E9E',
  surface700: '#616161',
  surface900: '#212121'
};
var error = {
  error50: '#ffebef',
  error900: '#C7001D'
};
var warning = {
  warning50: '#FFF7E1',
  warning800: '#FA8C15'
};
var success = {
  success50: '#E5F4E9',
  success700: '#00893D'
};
var texts = {
  text038: '#00000061',
  text060: '#00000099',
  text087: '#000000DE',
  text025: '#FFFFFF',
  text600: '#1E88E5',
  text900: '#9E0017'
};
var buttons = {
  buttonRed: primarys.primary700,
  buttonBlue: secondarys.secondary600
};
var semantics = {
  white: '#FFFFFF',
  black: '#000000',
  backgroundIOS: '#34C759',
  grayIOS: 'rgba(242, 242, 242, 0.8)',

  /**
   * Main body text color
   * @type {string}
   */
  text: texts.text087,

  /**
   * De-emphasized / footer text color
   * @type {string}
   */
  textLighter: texts.text060,

  /**
   * Regular hyperlinks color
   * @type {string}
   */
  link: texts.text600,

  /**
   * Primary brand color for links, buttons, etc.
   * @type {string}
   */
  primary: primarys.primary700,

  /**
   * A secondary brand color for alternative styling
   * @type {string}
   */
  secondary: secondarys.secondary600,
  green: greens.green600,
  yellow: yellows.yellow600,

  /**
   * Color for borders
   */
  border: grays.gray500,
  background: grays.gray300
};

var colors = /*#__PURE__*/_extends({}, primarys, secondarys, neutrals, greens, yellows, grays, surfaces, error, success, warning, texts, semantics, yellows, greens, buttons);
/**
 *  * theme.radi
 *
 * border-radius
 */


var radii = {
  /**
   * No border radius
   */
  none: 0,

  /**
   * Used for images, thumbnails
   */
  xs: '2px',

  /**
   * Used for buttons
   */
  sm: '4px',

  /**
   * Unused
   */
  md: '8px',

  /**
   * Unused
   */
  lg: '14px',

  /**
   * Used for c2c home page thumbnails
   */
  xl: '20px',

  /**
   * Used for pill buttons
   *
   * '9999px'
   */
  pill: '9999px',

  /**
   * Used for icons frames
   *
   * '100%'
   */
  circle: '100%'
};
var zIndices = {
  initial: 'auto',
  neutral: 0,
  up: 1,
  down: -1,
  notification: 1900,
  tooltip: 1800,
  modal: 1700,
  dropdown: 1600
};
/**
 * Whole theme object
 */

var theme = /*#__PURE__*/Object.freeze({
  breakpoints: /*#__PURE__*/_extends({}, breakpoints, {
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px',
    xxl: '1400px'
  }),
  mediaQueries: mediaQueries,
  sizes: sizes,
  fonts: fonts,
  fontWeights: fontWeights,
  colors: /*#__PURE__*/_extends({}, colors, {
    line: '#ddd'
  }),
  radii: radii,
  inputHeights: inputHeights,
  texts: texts,
  zIndices: zIndices
});

/**
 * Default theme. Basically, it's the same with ./mudah.tsx
 */

var _templateObject;
var colors$1 = theme.colors,
    fonts$1 = theme.fonts;
var ButtonStyle = /*#__PURE__*/styled.button(_templateObject || (_templateObject = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  cursor: pointer;\n  display: inline-flex;\n  align-items: center;\n  border: none;\n  text-decoration: none;\n  padding: 0.5rem 1rem;\n  border-radius: 0.5rem;\n  font-size: 0.88rem;\n  line-height: 1.25rem;\n  font-weight: 600;\n  font-family: ", ";\n  height: fit-content;\n  user-select: none;\n  outline: none;\n\n &.pri {\n    color: ", ";\n    background-color: ", ";\n    border-color: ", ";\n    &:hover {\n      color: ", ";\n      background-color: ", ";\n      border-color: ", ";\n    }\n    &:active {\n      color: ", ";\n      background-color: ", ";\n      border-color: ", ";\n    }\n  }\n\n  &.sec {\n    color: ", ";\n    background-color: ", ";\n    border-color: ", ";\n    &:hover {\n      color: ", ";\n      background-color: ", ";\n      border-color: ", ";\n    }\n    &:active {\n      color: ", ";\n      background-color: ", ";\n      border-color: ", ";\n    }\n  }\n\n  &.net {\n    color: ", ";\n    background-color: ", ";\n    border-color: ", ";\n    &:hover {\n      color: ", ";\n      background-color: ", ";\n      border-color: ", ";\n    }\n    &:active {\n      color: ", ";\n      background-color: ", ";\n      border-color: ", ";\n    }\n  }\n\n  &.hi {\n    color:  ", ";\n    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);\n    &:hover {\n      color:  ", ";\n    }\n    &:active {\n      color:  ", ";\n    }\n  }\n\n  &.med {\n    border-style: solid;\n    border-width: 1px;\n    background: transparent;\n    &:hover {\n      background: transparent;\n    }\n    &:active {\n      background: transparent;\n    }\n  }\n\n  &.low {\n    background-color: transparent;\n    box-shadow: none;\n    &:hover {\n      background-color: transparent;\n    }\n    &:active {\n      background-color: transparent;\n    }\n  }\n\n  &.hyperlink {\n    cursor: pointer;\n    display: inline-flex;\n    align-items: center;\n    border: none;\n    font-size: 1rem;\n    line-height: 1.5rem;\n    padding: 0;\n    font-weight: 400;\n    background-color: transparent;\n    box-shadow: none;\n    color: ", ";\n    text-decoration: underline;\n\n    &:hover {\n      color: ", ";\n      background-color: transparent;\n      text-decoration: underline;\n    }\n    &:active {\n      color: ", ";\n      background-color: transparent;\n      text-decoration: underline;\n    }\n  }\n\n  /* Inner icons */\n  svg {\n    margin-right: 0.66em;\n    font-size: 1.1rem;\n  }\n\n  &:focus {\n    outline: none;\n  }\n\n  &.disabled,\n  &:disabled,\n  &[disabled] {\n    opacity: 0.4;\n    cursor: default;\n    pointer-events: none;\n  }\n"])), fonts$1.body, colors$1.primary, colors$1.primary, colors$1.primary, colors$1.primary500, colors$1.primary500, colors$1.primary500, colors$1.primary900, colors$1.primary900, colors$1.primary900, colors$1.secondary, colors$1.secondary, colors$1.secondary, colors$1.secondary400, colors$1.secondary400, colors$1.secondary400, colors$1.secondary700, colors$1.secondary700, colors$1.secondary700, colors$1.gray600, colors$1.gray600, colors$1.gray600, colors$1.gray500, colors$1.gray500, colors$1.gray500, colors$1.gray800, colors$1.gray800, colors$1.gray800, colors$1.white, colors$1.white, colors$1.white, colors$1.secondary, colors$1.secondary400, colors$1.secondary700);

var _excluded = ["id", "disabled", "styles", "children", "className"];
var STYLES = ['btn-pri-hi', 'btn-sec-hi', 'btn-net-hi', 'btn-pri-med', 'btn-sec-med', 'btn-net-med', 'btn-pri-low', 'btn-sec-low', 'btn-net-low', 'hyperlink'];
var Button = /*#__PURE__*/React.forwardRef(function (_ref, ref) {
  var _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      styles = _ref.styles,
      children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _React$useState = React.useState('pri'),
      color = _React$useState[0],
      setColor = _React$useState[1];

  var _React$useState2 = React.useState('hi'),
      type = _React$useState2[0],
      setType = _React$useState2[1];

  var classname = styles || (className == null ? void 0 : className.split(' ').reverse().find(function (value) {
    return STYLES.includes(value);
  }));
  React.useEffect(function () {
    if (classname) {
      if (classname !== 'hyperlink') {
        var _classname$split, _classname$split2;

        setColor((_classname$split = classname.split('-')) == null ? void 0 : _classname$split[1]);
        setType((_classname$split2 = classname.split('-')) == null ? void 0 : _classname$split2[2]);
      } else {
        setColor('hyperlink');
      }
    }
  }, [classname]);

  var attrs = _extends({
    ref: ref
  }, props);

  return React.createElement(ButtonStyle, Object.assign({}, attrs, {
    className: "btn " + color + " " + type + " " + (disabled && 'disabled') + " " + className + " " + styles
  }), children);
});

var _templateObject$1, _templateObject2, _templateObject3, _templateObject4, _templateObject5;
var colors$2 = theme.colors;
var CheckboxContainer = /*#__PURE__*/styled.div(_templateObject$1 || (_templateObject$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n"])));
var ContextWrapper = /*#__PURE__*/styled.div(_templateObject2 || (_templateObject2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: column;\n  margin-right: 1.7rem;\n  font-weight: 700;\n  font-size: 14px;\n  line-height: 1.25rem;\n  color: ", ";\n  width: 17.5rem;\n\n  &.switch {\n    width: 16.8rem;\n  }\n"])), colors$2.text);
var Label = /*#__PURE__*/styled.span(_templateObject3 || (_templateObject3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  overflow: hidden;\n  text-overflow: ellipsis;\n\n  &.disabled {\n    opacity: 0.38;\n  }\n"])));
var Description = /*#__PURE__*/styled.span(_templateObject4 || (_templateObject4 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  font-weight: 400;\n  font-size: 12px;\n  line-height: 1rem;\n  margin-top: 4px;\n\n  &.disabled {\n    opacity: 0.38;\n  }\n"])));
/**
 *  @type {React.FC<any>}
 */

var StyledCheckbox = /*#__PURE__*/styled.label(_templateObject5 || (_templateObject5 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  position: relative;\n  cursor: pointer;\n  height: max-content;\n\n  & > input {\n    visibility: hidden;\n    width: 0;\n    height: 0;\n  }\n\n  & > span {\n    color: ", ";\n    position: relative;\n    display: inline-block;\n    border: 2px solid;\n    height: 20px;\n    width: 20px;\n  }\n\n  & > .checkbox {\n    border-radius: 4px;\n    height: 18px;\n    width: 18px;\n    &.isIOS{\n      height: 22px;\n      width: 22px;\n      border-radius: 8px;\n    }\n  }\n\n  & > .radio {\n    border-radius: 100%;\n    &.isIOS {\n      height: 22px;\n      width: 22px;\n    }\n  }\n\n  & > .switch {\n    width: 34px;\n    height: 14px;\n    border-radius: 7px;\n    background: rgba(0, 0, 0, 0.2);\n    color: transparent;\n\n    :after {\n      content: '';\n      position: absolute;\n      left: -2px;\n      top: -5px;\n      width: 20px;\n      height: 20px;\n      border-radius: 100%;\n      z-index: 0;\n      transition-duration: 150ms;\n      background: ", ";\n      box-shadow: 0 1px 1px rgba(0, 0, 0, 0.14), 0 2px 1px rgba(0, 0, 0, 0.12), 0 1px 3px rgba(0, 0, 0, 0.2);\n    }\n\n    &.isIOS {\n      width: 51px;\n      height: 31px;\n      border-radius: 25px;\n      background: rgba(120, 120, 128, 0.16);\n\n      &:after {\n        left: 0;\n        top: 0;\n        width: 27px;\n        height: 27px;\n        box-shadow: none;\n      }\n    }\n  }\n\n  input:checked {\n    + .checkbox {\n      color: ", ";\n      background: ", ";\n\n      &:after {\n        content: '';\n        position: absolute;\n        left: 4px;\n        top: 0;\n        width: 7px;\n        height: 12px;\n        border: solid ", ";\n        border-width: 0 2px 2px 0;\n        transform: rotate(45deg);\n      }\n\n      &.isIOS:after {\n        left: 6px;\n        top: 2px;\n        width: 6px;\n        height: 11px;\n        border-width: 0 2px 2px 0;\n      }\n    }\n\n    + .radio {\n      background: ", ";\n      color: ", ";\n\n      &:after {\n        content: '';\n        position: absolute;\n        background-color: ", ";\n        border-radius: 100%;\n        left: 3px;\n        top: 3px;\n        width: 10px;\n        height: 10px;\n      }\n\n      &.isIOS:after {\n        left: 1px;\n        top: 1px;\n        width: 16px;\n        height: 16px;\n      }\n    }\n\n    + .switch {\n      background: ", ";\n\n      &:after {\n        transform: translateX(14px);\n        background: ", ";\n        box-shadow: 0 3px 8px rgba(0, 0, 0, 0.15), 0 3px 1px rgba(0, 0, 0, 0.06);\n      }\n\n      &.isIOS {\n        background: ", ";\n\n        :after {\n          transform: translateX(20px);\n          background: ", ";\n        }\n      }\n    }\n  }\n\n  &.disabled {\n    opacity: 0.38;\n    cursor: auto;\n  }\n"])), colors$2.gray500, colors$2.white, function (_ref) {
  var colorCheckbox = _ref.colorCheckbox;
  return colorCheckbox;
}, function (_ref2) {
  var colorCheckbox = _ref2.colorCheckbox;
  return colorCheckbox;
}, colors$2.white, colors$2.white, function (_ref3) {
  var colorCheckbox = _ref3.colorCheckbox;
  return colorCheckbox;
}, function (_ref4) {
  var colorCheckbox = _ref4.colorCheckbox;
  return colorCheckbox;
}, function (_ref5) {
  var colorCheckbox = _ref5.colorCheckbox;
  return colorCheckbox + "61";
}, function (_ref6) {
  var colorCheckbox = _ref6.colorCheckbox;
  return colorCheckbox;
}, function (_ref7) {
  var colorCheckbox = _ref7.colorCheckbox;
  return colorCheckbox === colors$2.secondary ? colors$2.backgroundIOS : colorCheckbox;
}, colors$2.white);

var _excluded$1 = ["label", "description", "className", "type", "checked", "color", "disabled"];
var colors$3 = theme.colors;
var Checkbox = function Checkbox(_ref) {
  var label = _ref.label,
      description = _ref.description,
      className = _ref.className,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'checkbox' : _ref$type,
      _ref$checked = _ref.checked,
      checked = _ref$checked === void 0 ? false : _ref$checked,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'secondary' : _ref$color,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$1);

  var inputAttrs = _extends({
    type: type === 'switch' ? 'checkbox' : type,
    disabled: disabled
  }, props);

  var colorCheckbox = (colors$3 == null ? void 0 : colors$3[color]) || color || colors$3.secondary;
  var disabledClass = disabled ? 'disabled' : '';
  var isIOSClass = isIOS ? 'isIOS' : '';
  var checkboxClasses = className + " " + disabledClass;
  return React.createElement(CheckboxContainer, null, (label || description) && React.createElement(ContextWrapper, {
    className: type
  }, label && React.createElement(Label, {
    className: disabledClass
  }, label), description && React.createElement(Description, {
    className: disabledClass
  }, description)), React.createElement(StyledCheckbox, {
    className: checkboxClasses,
    colorCheckbox: colorCheckbox
  }, React.createElement("input", Object.assign({}, inputAttrs, {
    checked: checked
  })), React.createElement("span", {
    className: type + " " + isIOSClass
  })));
};

/**
 * A no-ops function used for default function props to avoid
 * re-creation of functions everytime a component is re-rendered
 *
 * @return {void} undefined
 */
var noop = function noop() {};

/**
 * Calls ReactDOM.createPortal at client side or push to createUniversalPortal.portals at server side
 */

var createUniversalPortal = function createUniversalPortal(children) {
  if (typeof window !== 'undefined' && typeof document !== 'undefined') {
    // client side
    return ReactDOM.createPortal(children, document.body);
  } else {
    // server side
    // TODO: should we take care of removing portal instances?
    return createUniversalPortal.portals.push(children);
  }
};

createUniversalPortal.portals = [];

/**
 * Takes a list of class names and filters for truthy ones, joining them into a single class name for convenience.
 * eg.
 * ```js
 *  cx('red', isBig && 'big') // returns 'red big' if `isBig` is true, otherwise returns 'red'
 * ```
 * If space separated atomic styles are provided, they are deduplicated according to the first hashed valued:
 *
 * ```js
 *  cx('atm_a_class1 atm_b_class2', 'atm_a_class3') // returns `atm_a_class3 atm_b_class2`
 * ```
 *
 * @returns the combined, space separated class names that can be applied directly to the class attribute
 */
var cx = function cx() {
  var presentClassNames = Array.prototype.slice // eslint-disable-next-line prefer-rest-params
  .call(arguments).filter(Boolean);
  var atomicClasses = {};
  var nonAtomicClasses = [];
  presentClassNames.forEach(function (arg) {
    // className could be the output of a previous cx call, so split by ' ' first
    var individualClassNames = arg ? arg == null ? void 0 : arg.split(' ') : [];
    individualClassNames.forEach(function (className) {
      if (className.startsWith('atm_')) {
        var _className$split = className.split('_'),
            keyHash = _className$split[1];

        atomicClasses[keyHash] = className;
      } else {
        nonAtomicClasses.push(className);
      }
    });
  });
  var result = []; // eslint-disable-next-line no-restricted-syntax

  for (var keyHash in atomicClasses) {
    if (Object.prototype.hasOwnProperty.call(atomicClasses, keyHash)) {
      result.push(atomicClasses[keyHash]);
    }
  }

  result.push.apply(result, nonAtomicClasses);
  return result.join(' ');
};

var _templateObject$2, _templateObject2$1;
var colors$4 = theme.colors;
/**
 *  @type {React.FC<any>}
 */

var ChipStyle = /*#__PURE__*/styled.button(_templateObject$2 || (_templateObject$2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: inline-flex;\n  border-radius: 40px;\n  color: ", ";\n  border-width: 1px;\n  border-style: solid;\n  border-color: ", ";\n  background: ", ";\n  align-items: center;\n  padding: 4px;\n\n\n  .prefixIcon {\n    display: contents;\n    svg {\n      color: ", ";\n      width: 1.5rem;\n      height: 1.5rem;\n    }\n  }\n\n  .suffixIcon{\n    display: contents;\n    svg {\n      color: ", ";\n      width: 18px;\n      height: 18px;\n      margin-right: 4px;\n    }\n  }\n\n  &:hover, &.isActive {\n    color: ", ";\n    border-color: ", ";\n    svg {\n      color: ", ";\n    }\n  }\n  &.isActive {\n    background: ", ";\n  }\n\n  &.disabled, &[disabled] {\n    color: ", ";\n    background: ", ";\n    pointer-events: none;\n    border-color: ", ";\n    svg {\n      color: ", ";\n    }\n  }\n\n  &:focus {\n    outline: none;\n  }\n"])), colors$4.text, colors$4.gray300, colors$4.white, colors$4.text, colors$4.text, function (_ref) {
  var color = _ref.color;
  return color;
}, function (_ref2) {
  var color = _ref2.color;
  return color + "33";
}, function (_ref3) {
  var color = _ref3.color;
  return color;
}, function (_ref4) {
  var color = _ref4.color;
  return color + "33";
}, colors$4.text038, colors$4.gray100, colors$4.gray100, colors$4.text038);
var LableChip = /*#__PURE__*/styled.span(_templateObject2$1 || (_templateObject2$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  line-height: 1.38rem;\n  font-weight: 400;\n  font-size: 14px;\n  margin: 0 8px;\n"])));

var icons = {
  check: {
    html: "<path fill=\"currentColor\" d=\"M6.096 12L0 6.154l2.104-2.04 3.935 3.773L13.839 0 16 1.986z\" />",
    info: {
      viewBox: "0 0 16 12",
      width: "1em",
      height: "1em"
    }
  },
  "add-circle-outline": {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path fill="currentColor" d="M11 11V7h2v4h4v2h-4v4h-2v-4H7v-2h4zm1 11C6.477 22 2 17.523 2 12S6.477 2 12 2s10 4.477 10 10-4.477 10-10 10zm0-2a8 8 0 1 0 0-16 8 8 0 0 0 0 16z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "minus-circle-outline": {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path fill="currentColor" d="M12 22C6.477 22 2 17.523 2 12S6.477 2 12 2s10 4.477 10 10-4.477 10-10 10zm0-2a8 8 0 1 0 0-16 8 8 0 0 0 0 16zm-5-9h10v2H7v-2z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "alert-circle": {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path fill="currentColor" d="M12 22C6.477 22 2 17.523 2 12S6.477 2 12 2s10 4.477 10 10-4.477 10-10 10zm-1-7v2h2v-2h-2zm0-8v6h2V7h-2z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  close: {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path fill="currentColor" d="M12 10.586l4.95-4.95 1.414 1.414-4.95 4.95 4.95 4.95-1.414 1.414-4.95-4.95-4.95 4.95-1.414-1.414 4.95-4.95-4.95-4.95L7.05 5.636z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "chevron-down": {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path d="M12 13.172l4.95-4.95 1.414 1.414L12 16 5.636 9.636 7.05 8.222z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "chevron-up": {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path d="M12 10.828l-4.95 4.95-1.414-1.414L12 8l6.364 6.364-1.414 1.414z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "chevron-right": {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path d="M13.172 12l-4.95-4.95 1.414-1.414L16 12l-6.364 6.364-1.414-1.414z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "chevron-left": {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path d="M10.828 12l4.95 4.95-1.414 1.414L8 12l6.364-6.364 1.414 1.414z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "rotate-left": {
    html: '<path fill="none" d="M0,0H24V24H0Z" /><path fill="currentColor" d="M8.38,5.55,12.93,1V4.07a7.992,7.992,0,0,1,0,15.86V17.91a5.993,5.993,0,0,0,0-11.82V10ZM4,11A7.906,7.906,0,0,1,5.62,7.11L7.04,8.53A5.806,5.806,0,0,0,6.02,11Zm6.93,6.9v2.02a7.924,7.924,0,0,1-3.9-1.61l1.44-1.44a5.786,5.786,0,0,0,2.46,1.03ZM7.04,15.48,5.62,16.89A7.906,7.906,0,0,1,4,13H6.02A5.9,5.9,0,0,0,7.04,15.48Z" transform="translate(-0.132)" />',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "rotate-right": {
    html: '<path fill="none" d="M0,0H24V24H0Z" /><path fill="currentColor" d="M16,6,11,1V4a8.071,8.071,0,0,0,0,16V18A6.1,6.1,0,0,1,11,6v4Zm4,5a8.959,8.959,0,0,0-2-4L17,9a4.126,4.126,0,0,1,1,2Zm-7,7v2a8.959,8.959,0,0,0,4-2l-2-1A4.126,4.126,0,0,1,13,18Zm4-3,1,2a8.959,8.959,0,0,0,2-4H18A4.169,4.169,0,0,1,17,15Z" />',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  delete: {
    html: '<path fill="currentColor" d="M6,18.7a2.006,2.006,0,0,0,2,2h8a2.006,2.006,0,0,0,2-2V6.7H6Zm13-15H16l-1-1H10l-1,1H5v2H19Z" transform="translate(0 0.296)" /><path fill="none" d="M0-.3H24v24H0Z" transform="translate(0 0.296)" />',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  edit: {
    html: '<rect id="Rectangle_3922" width="24" height="24" rx="4" fill="currentColor"/><g id="edit-18px" transform="translate(4 4)"><rect id="Rectangle_3921" width="16" height="16" fill="none"/><path id="Path_6550" d="M15.333,16.666H2V14H15.333ZM9.373,4.126l2.5,2.5-6.04,6.04h-2.5v-2.5Zm3.213,1.787-2.5-2.5,1.22-1.22a.664.664,0,0,1,.94,0l1.56,1.56a.664.664,0,0,1,0,.94Z" transform="translate(-0.667 -0.666)" fill="#fff"/></g>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  download: {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path d="M13 10h5l-6 6-6-6h5V3h2v7zm-9 9h16v-7h2v8a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1v-8h2v7z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "arrow-left": {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path d="M7.828 11H20v2H7.828l5.364 5.364-1.414 1.414L4 12l7.778-7.778 1.414 1.414z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  search: {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path fill="currentColor" d="M18.031 16.617l4.283 4.282-1.415 1.415-4.282-4.283A8.96 8.96 0 0 1 11 20c-4.968 0-9-4.032-9-9s4.032-9 9-9 9 4.032 9 9a8.96 8.96 0 0 1-1.969 5.617zm-2.006-.742A6.977 6.977 0 0 0 18 11c0-3.868-3.133-7-7-7-3.868 0-7 3.132-7 7 0 3.867 3.132 7 7 7a6.977 6.977 0 0 0 4.875-1.975l.15-.15z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  info: {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path fill="currentColor" d="M12 22C6.477 22 2 17.523 2 12S6.477 2 12 2s10 4.477 10 10-4.477 10-10 10zm0-2a8 8 0 1 0 0-16 8 8 0 0 0 0 16zM11 7h2v2h-2V7zm0 4h2v6h-2v-6z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "arrow-down-fill": {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path d="M12 16l-6-6h12z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "arrow-up-fill": {
    html: '<path fill="none" d="M0 0h24v24H0z"/><path d="M12 8l6 6H6z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  },
  "pan-tool-alt": {
    html: '<path d="M19.98,14.82l-0.63,4.46C19.21,20.27,18.36,21,17.37,21h-6.16c-0.53,0-1.29-0.21-1.66-0.59L5,15.62l0.83-0.84 c0.24-0.24,0.58-0.35,0.92-0.28L10,15.24V4.5C10,3.67,10.67,3,11.5,3S13,3.67,13,4.5v6h0.91c0.31,0,0.62,0.07,0.89,0.21l4.09,2.04 C19.66,13.14,20.1,13.97,19.98,14.82z"/>',
    info: {
      viewBox: "0 0 24 24",
      width: "24",
      height: "24"
    }
  }
};

var iconSizes = {
  sm: ["w-3", "h-3"],
  md: ["w-4", "h-4"],
  lg: ["w-6", "h-6"],
  xl: ["w-8", "h-8"]
};
function getIconStyles(_ref) {
  var fill = _ref.fill,
      size = _ref.size;
  var styles = ["align-middle", "inline-block"];

  if (fill === "fill-current") {
    styles.push(fill);
  }

  if (size !== "unset") {
    styles.push.apply(styles, iconSizes[size]);
  }

  return styles.join(" ");
}

var _excluded$2 = ["name", "size", "fill", "className"];
var Icon = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var name = _ref.name,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? "unset" : _ref$size,
      _ref$fill = _ref.fill,
      fill = _ref$fill === void 0 ? "fill-current" : _ref$fill,
      className = _ref.className,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$2);

  var _icons$name = icons[name],
      html = _icons$name.html,
      info = _icons$name.info;
  var viewBox = info.viewBox;
  var width = info.width,
      height = info.height;
  var finalClass = getIconStyles({
    fill: fill,
    size: size
  }) + " " + className;
  return React.createElement("svg", Object.assign({
    ref: ref,
    className: finalClass,
    dangerouslySetInnerHTML: {
      __html: html
    },
    height: size === "unset" ? height : undefined,
    viewBox: viewBox,
    width: size === "unset" ? width : undefined
  }, rest));
});

var _excluded$3 = ["label", "value", "color", "disabled", "onChange", "className", "prefixIcon", "suffixIcon"];
var colors$5 = theme.colors;
var Chip = function Chip(_ref) {
  var _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? false : _ref$value,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'primary' : _ref$color,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? noop : _ref$onChange,
      className = _ref.className,
      prefixIcon = _ref.prefixIcon,
      suffixIcon = _ref.suffixIcon,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$3);

  var attrs = _extends({
    disabled: disabled
  }, props);

  var colorChip = (colors$5 == null ? void 0 : colors$5[color]) || color || colors$5.primary;
  var disabledClass = disabled ? 'disabled' : '';
  var isActiveClass = value ? 'isActive' : '';
  var chipClasses = className + " " + disabledClass + " " + isActiveClass;

  var handleClick = function handleClick() {
    return onChange(!value);
  };

  return React.createElement(ChipStyle, Object.assign({}, attrs, {
    color: colorChip,
    className: chipClasses,
    onClick: handleClick
  }), prefixIcon && React.createElement("span", {
    className: "prefixIcon"
  }, typeof prefixIcon === "string" ? React.createElement("span", {
    className: "prefixIcon"
  }, React.createElement(Icon, {
    name: prefixIcon
  })) : prefixIcon), React.createElement(LableChip, null, label), suffixIcon && React.createElement("span", {
    className: "prefixIcon"
  }, typeof suffixIcon === "string" ? React.createElement("span", {
    className: "suffixIcon"
  }, React.createElement(Icon, {
    name: suffixIcon
  })) : suffixIcon));
};

var _templateObject$3, _templateObject2$2, _templateObject3$1, _templateObject4$1, _templateObject5$1, _templateObject6, _templateObject7, _templateObject8;
var colors$6 = theme.colors,
    radii$1 = theme.radii,
    sizes$1 = theme.sizes,
    zIndices$1 = theme.zIndices,
    fonts$2 = theme.fonts;
var Modal = /*#__PURE__*/styled.div(_templateObject$3 || (_templateObject$3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: grid;\n  place-items: center;\n  position: fixed;\n  top: 0;\n  left: 0;\n  width: ", ";\n  height: ", ";\n  padding: 0.75rem;\n  z-index: ", ";\n  font-family: ", ";\n"])), sizes$1.vW, sizes$1.vH, zIndices$1.modal, fonts$2.body);
var Backdrop = /*#__PURE__*/styled.div(_templateObject2$2 || (_templateObject2$2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  background-color: ", ";\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: ", ";\n  height: ", ";\n  opacity: 0.3;\n"])), colors$6.black, sizes$1.full, sizes$1.full);
var StyledDialog = /*#__PURE__*/styled.div(_templateObject3$1 || (_templateObject3$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: 100%;\n  max-width: 21.5rem;\n  overflow-x: hidden;\n  overflow-y: auto;\n  box-shadow: 0 12px 36px rgba(0, 0, 0, 0.25);\n  z-index: ", ";\n  background-color: ", ";\n  border-radius: ", ";\n  max-height: 35rem;\n\n  &.isLargeSize {\n    max-width: 35rem;\n  }\n\n  &.isIOS {\n    background-color: ", ";\n    backdrop-filter: blur(22px);\n    border-radius: 14px;\n  }\n"])), zIndices$1.up, colors$6.white, radii$1.sm, colors$6.grayIOS);
var ContextWrapper$1 = /*#__PURE__*/styled.div(_templateObject4$1 || (_templateObject4$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  position: relative;\n  width: ", ";\n  padding: 1.5rem 2rem;\n\n  .title {\n    font-weight: 600;\n    font-size: 1.25rem;\n    line-height: 1.75rem;\n    color: ", ";\n    margin-bottom: 1rem;\n  }\n\n  &.isMobile {\n    padding: 1.5rem 1rem;\n    .title {\n      font-size: 1rem;\n      font-weight: 700;\n      line-height: 1.38rem;\n    }\n\n    &.isIOS {\n      padding: 1rem 1rem 0;\n      .title {\n        color: ", ";\n        font-size: 17px;\n        font-weight: 600;\n        line-height: 1.38rem;\n        letter-spacing: -0.41px;\n        text-align: center;\n        margin-bottom: 2px;\n      }\n    }\n  }\n\n  &.hasImage {\n    padding-top: 1rem;\n  }\n"])), sizes$1.full, colors$6.text, colors$6.black);
var Image = /*#__PURE__*/styled.img(_templateObject5$1 || (_templateObject5$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: 100%;\n  object-fit: cover;\n"])));
var ChildrenWrapper = /*#__PURE__*/styled.div(_templateObject6 || (_templateObject6 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  max-height: calc(", " - 280px);\n  overflow-y: hidden;\n  color: ", ";\n  font-weight: 400;\n  font-size: 14px;\n  line-height: 22px;\n  margin-bottom: 1rem;\n\n  &.no-button {\n    max-height: calc(", " - 224px);\n    margin-bottom: 0;\n  }\n\n  &.is-single-string {\n    white-space: pre-wrap;\n  }\n\n  &.isIOS {\n    font-size: 13px;\n    line-height: 18px;\n    text-align: center;\n    letter-spacing: -0.078px;\n  }\n"])), sizes$1.vH, colors$6.text060, sizes$1.vH);
var ButtonWrapper = /*#__PURE__*/styled.div(_templateObject7 || (_templateObject7 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: row-reverse;\n\n  button{\n    margin-top: 0.75rem;\n    margin-left: 8px;\n    text-transform: uppercase;\n  }\n\n  .buttonAction2, .buttonAction3 {\n    color: ", ";\n  }\n\n  &.isMobileVertical {\n    flex-wrap: wrap;\n    align-items: flex-end;\n    flex-direction: column;\n  }\n\n  &.isIOS {\n    margin: 0 -1rem;\n    border-top: 0.5px solid rgba(60, 60, 67, 0.36);\n    button {\n      flex: 1;\n      justify-content: center;\n      margin-top: 0;\n      padding: 12px 0;\n      width: 100%;\n      margin-left: 0;\n      border-radius: 0;\n      background: transparent;\n      text-transform: capitalize;\n      color: ", ";\n\n      &.buttonAction2, &.buttonAction3 {\n        font-weight: 400;\n      }\n    }\n    &.isMobileVertical {\n      align-items: center;\n    }\n  }\n"])), colors$6.text, colors$6.secondary);
var Separator = /*#__PURE__*/styled.span(_templateObject8 || (_templateObject8 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: 0.5px;\n  height: auto;\n  background: rgba(60, 60, 67, 0.36);\n\n  &.isIOS.isMobileVertical {\n    width: 100%;\n    height: 0.5px;\n  }\n"])));

var _excluded$4 = ["image", "title", "children", "className", "btnLabel1", "btnLabel2", "btnLabel3", "isLargeSize", "open", "isMobileVertical", "onClose", "onButtonClick1", "onButtonClick2", "onButtonClick3"];
var Dialog = function Dialog(_ref) {
  var image = _ref.image,
      title = _ref.title,
      children = _ref.children,
      className = _ref.className,
      _ref$btnLabel = _ref.btnLabel1,
      btnLabel1 = _ref$btnLabel === void 0 ? 'confirm' : _ref$btnLabel,
      _ref$btnLabel2 = _ref.btnLabel2,
      btnLabel2 = _ref$btnLabel2 === void 0 ? 'cancel' : _ref$btnLabel2,
      btnLabel3 = _ref.btnLabel3,
      _ref$isLargeSize = _ref.isLargeSize,
      isLargeSize = _ref$isLargeSize === void 0 ? false : _ref$isLargeSize,
      _ref$open = _ref.open,
      open = _ref$open === void 0 ? false : _ref$open,
      _ref$isMobileVertical = _ref.isMobileVertical,
      isMobileVertical = _ref$isMobileVertical === void 0 ? false : _ref$isMobileVertical,
      _ref$onClose = _ref.onClose,
      onClose = _ref$onClose === void 0 ? noop : _ref$onClose,
      _ref$onButtonClick = _ref.onButtonClick1,
      onButtonClick1 = _ref$onButtonClick === void 0 ? noop : _ref$onButtonClick,
      _ref$onButtonClick2 = _ref.onButtonClick2,
      onButtonClick2 = _ref$onButtonClick2 === void 0 ? noop : _ref$onButtonClick2,
      _ref$onButtonClick3 = _ref.onButtonClick3,
      onButtonClick3 = _ref$onButtonClick3 === void 0 ? noop : _ref$onButtonClick3,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$4);

  var childrenWrapperClasses = typeof children === 'string' || typeof children === 'number' ? 'is-single-string' : '';
  var isLargeSizeClass = isLargeSize ? 'isLargeSize' : '';
  var imageClass = image ? 'hasImage' : '';
  var isMobileClass = isMobile ? 'isMobile' : '';
  var isIOSClass = isIOS ? 'isIOS' : '';
  var isMobileVerticalClass = isMobileVertical && isMobile ? 'isMobileVertical' : '';
  return React.createElement("div", null, open && createUniversalPortal(React.createElement(Modal, Object.assign({}, props), React.createElement(Backdrop, {
    onClick: onClose
  }), React.createElement(StyledDialog, {
    className: className + " " + isLargeSizeClass + " " + isIOSClass
  }, image && (typeof image === 'string' ? React.createElement(Image, {
    className: "image",
    src: image,
    alt: "image"
  }) : image), React.createElement(ContextWrapper$1, {
    className: imageClass + " " + isMobileClass + " " + isIOSClass
  }, title && React.createElement("div", {
    className: "title"
  }, title), React.createElement(ChildrenWrapper, {
    className: childrenWrapperClasses
  }, children), React.createElement(ButtonWrapper, {
    className: isMobileVerticalClass + " " + isIOSClass
  }, btnLabel1 && React.createElement(React.Fragment, null, React.createElement(Button, {
    styles: "btn-pri-low",
    className: "buttonAction1",
    onClick: onButtonClick1
  }, btnLabel1), isIOS && React.createElement(Separator, {
    className: isMobileVerticalClass + " " + isIOSClass
  })), btnLabel2 && React.createElement(Button, {
    styles: "btn-net-low",
    className: "buttonAction2",
    onClick: onButtonClick2
  }, btnLabel2), btnLabel3 && React.createElement(React.Fragment, null, isIOS && React.createElement(Separator, {
    className: isMobileVerticalClass + " " + isIOSClass
  }), React.createElement(Button, {
    styles: "btn-net-low",
    className: "buttonAction3",
    onClick: onButtonClick3
  }, btnLabel3))))))));
};

var _templateObject$4, _templateObject2$3, _templateObject3$2, _templateObject4$2, _templateObject5$2, _templateObject6$1, _templateObject7$1, _templateObject8$1, _templateObject9, _templateObject10, _templateObject11, _templateObject12;
var colors$7 = theme.colors,
    sizes$2 = theme.sizes,
    fonts$3 = theme.fonts,
    radii$2 = theme.radii,
    fontWeights$1 = theme.fontWeights,
    texts$1 = theme.texts,
    inputHeights$1 = theme.inputHeights;
var InputContainer = /*#__PURE__*/styled.div(_templateObject$4 || (_templateObject$4 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  position: relative;\n  width: ", ";\n"])), sizes$2.full);
var Container = /*#__PURE__*/styled.div(_templateObject2$3 || (_templateObject2$3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: ", ";\n  position: relative;\n  font-family: ", ";\n"])), function (_ref) {
  var containerWidth = _ref.containerWidth;
  return containerWidth;
}, fonts$3.body);
var SubLabel = /*#__PURE__*/styled.label(_templateObject3$2 || (_templateObject3$2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  position: absolute;\n  left: 0;\n  cursor: text;\n  pointer-events: none;\n  transform-origin: top left;\n  transition: transform 0.1s ease;\n  color: ", ";\n  font-size: 1rem;\n\n  &.required::after {\n    content: '*';\n    margin-left: 4px;\n  }\n\n  &.focus {\n    background-color: ", ";\n    color: ", ";\n    padding: 0 4px;\n  }\n\n  &.focus, &.hasValue {\n    transform: translate(", "px, -26px);\n    background-color: ", ";\n    padding: 0 4px;\n    font-size: 0.75rem;\n  }\n  &.focus.small,\n  &.hasValue.small {\n    transform: translate(", "px, -16px);\n  }\n\n  &.error {\n    color: ", ";\n  }\n"])), colors$7.textLighter, colors$7.white, colors$7.secondary, function (_ref2) {
  var prefixWidth = _ref2.prefixWidth;
  return prefixWidth ? -16 - prefixWidth : -8;
}, colors$7.white, function (_ref3) {
  var prefixWidth = _ref3.prefixWidth;
  return prefixWidth ? -16 - prefixWidth : -8;
}, colors$7.primary900);
var InputStyle = /*#__PURE__*/styled.input(_templateObject4$2 || (_templateObject4$2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: ", ";\n  height: ", ";\n  font-size: 1rem;\n  color: ", ";\n  appearance: none;\n  outline: none;\n  border: none;\n  background-color: ", ";\n\n  &:disabled {\n    background-color: ", ";\n    cursor: default;\n  }\n  \n  padding: 0;\n  text-overflow: ellipsis;\n  caret-color: ", ";\n\n  &[disabled] {\n    color: rgba(0, 0, 0, 0.6);\n  }\n"])), sizes$2.full, sizes$2.full, colors$7.text, colors$7.white, colors$7.gray100, colors$7.secondary);
var TextareaStyle = /*#__PURE__*/styled.textarea(_templateObject5$2 || (_templateObject5$2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  height: 100%;\n  resize: none;\n  padding: 0;\n  caret-color: ", ";\n\n  &[disabled] {\n    color: rgba(0, 0, 0, 0.6);\n  }\n"])), colors$7.secondary);
var ParagraphWrapper = /*#__PURE__*/styled.div(_templateObject6$1 || (_templateObject6$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  justify-content: space-between;\n  color: ", ";\n  font-size: 0.75rem;\n  margin-left: 4px;\n  line-height: 1.5;\n  margin-top: 4px;\n  margin-bottom: 0;\n\n  &.error .assitiveText {\n    color: ", ";\n  }\n\n  &.isCharacterLimitError .characterLimit {\n    color: ", ";\n  }\n"])), colors$7.textLighter, colors$7.primary900, colors$7.primary900);
var InputWrapper = /*#__PURE__*/styled.div(_templateObject7$1 || (_templateObject7$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: row;\n  width: ", ";\n  height:  ", ";\n  position: relative;\n  border-radius: ", ";\n  border: 1px solid ", ";\n  background-color: #ffffff;\n  padding: 1rem 0.75rem;\n  font-family: ", ";\n  margin-top: 4px;\n\n  &.small {\n    height: ", ";\n    padding: 6px 12px;\n  }\n\n  &.longParagraph {\n    height: ", ";\n  }\n\n  &.longParagraph.disabled.noValue {\n    height: 148px;\n  }\n\n  &:focus-within {\n    border-color: ", ";\n  }\n\n  &.error {\n    border-color: ", ";\n  }\n\n  &.disabled {\n    background-color: ", ";\n    border: 1px solid rgba(0, 0, 0, 0.08);\n  }\n\n  & > button {\n    background: transparent;\n    outline: none;\n    border: none;\n    height: 32px;\n    min-width: 10rem;\n    position: absolute;\n    top: 0;\n    right: 2px;\n    color: ", ";\n    padding: 8px;\n  }\n\n  & > .password {\n    top: -1px;\n  }\n\n  & svg {\n    font-size: 0.75rem;\n  }\n"])), sizes$2.full, inputHeights$1.md, radii$2.sm, colors$7.border, fonts$3.body, inputHeights$1.sm, inputHeights$1.xs, colors$7.secondary, colors$7.primary900, colors$7.gray100, colors$7.link);
var SuffixWrapper = /*#__PURE__*/styled.div(_templateObject8$1 || (_templateObject8$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  align-items: ", ";\n  & svg {\n    font-size: 1.25rem;\n  }\n"])), function (_ref4) {
  var longParagraph = _ref4.longParagraph;
  return longParagraph ? 'start' : 'center';
});
var ErrorIcon = /*#__PURE__*/styled.span(_templateObject9 || (_templateObject9 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  color: ", ";\n  margin-left: 14px;\n  align-items: center;\n  display: flex;\n  & svg {\n    font-size: 1.25rem;\n  }\n"])), colors$7.primary900);
var IconWrapper = /*#__PURE__*/styled.div(_templateObject10 || (_templateObject10 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  margin-left: 14px;\n  display: flex;\n  align-items: center;\n  \n  &.dropdown svg {\n    color: ", ";\n    font-size: 10px;\n  }\n  &.disabled.dropdown svg {\n    color: ", ";\n  }\n\n  &.dropdown.focus > svg {\n    transform: rotateY(180);\n  }\n"])), colors$7.gray700, texts$1.text038);
var PrefixLabel = /*#__PURE__*/styled.div(_templateObject11 || (_templateObject11 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  margin-right: 8px;\n  font-size: 16px;\n  color: ", ";\n  text-transform: uppercase;\n  font-weight: ", ";\n"])), texts$1.text038, fontWeights$1.bold);
var SuffixLabel = /*#__PURE__*/styled.div(_templateObject12 || (_templateObject12 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  margin-left: 14px;\n  font-size: 16px;\n  color: ", ";\n  text-transform: uppercase;\n  font-weight: ", ";\n"])), texts$1.text038, fontWeights$1.bold);

var _excluded$5 = ["id", "name", "label", "value", "onBlur", "onFocus", "disabled", "required", "status", "assitiveText", "characterLimit", "longParagraph", "size", "icon", "prefix", "suffix", "placeholder"];
var sizes$3 = theme.sizes;
var Input = function Input(_ref) {
  var id = _ref.id,
      label = _ref.label,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value,
      _ref$onBlur = _ref.onBlur,
      onBlur = _ref$onBlur === void 0 ? noop : _ref$onBlur,
      _ref$onFocus = _ref.onFocus,
      onFocus = _ref$onFocus === void 0 ? noop : _ref$onFocus,
      disabled = _ref.disabled,
      required = _ref.required,
      _ref$status = _ref.status,
      status = _ref$status === void 0 ? 'default' : _ref$status,
      assitiveText = _ref.assitiveText,
      _ref$characterLimit = _ref.characterLimit,
      characterLimit = _ref$characterLimit === void 0 ? 0 : _ref$characterLimit,
      _ref$longParagraph = _ref.longParagraph,
      longParagraph = _ref$longParagraph === void 0 ? false : _ref$longParagraph,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size,
      icon = _ref.icon,
      prefix = _ref.prefix,
      suffix = _ref.suffix,
      placeholder = _ref.placeholder,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$5);

  var _useState = useState(0),
      prefixWidth = _useState[0],
      setPrefixWidth = _useState[1];

  var _useState2 = useState(false),
      isFocused = _useState2[0],
      setIsFocused = _useState2[1];

  var _useState3 = useState(status === 'error'),
      isWithError = _useState3[0],
      setIsWithError = _useState3[1];

  var isCharacterLimitError = characterLimit > 0 && value.toString().length > characterLimit;
  var sizeClass = size === 'small' ? 'small' : '';
  var hasValueClass = value ? 'hasValue' : '';
  var noValueClass = !value ? 'noValue' : '';
  var noLabelClass = !label ? 'noLabel' : '';
  var requiredClass = required ? 'required' : '';
  var isFocusedClass = isFocused ? 'focus' : '';
  var disabledClass = disabled ? 'disabled' : '';
  var isWithErrorClass = isWithError ? 'error' : '';
  var isCharacterLimitErrorClass = isCharacterLimitError ? 'isCharacterLimitError' : '';
  var hasIconClass = icon ? 'hasIcon' : '';
  var longParagraphClass = longParagraph ? 'longParagraph' : '';
  var containerWidth = sizes$3.full || 'initial';
  var className = sizeClass + " " + hasValueClass + " " + noLabelClass + " " + requiredClass + " " + isFocusedClass;
  var wrapperClassname = disabledClass + " " + isWithErrorClass + " " + isCharacterLimitErrorClass + " " + sizeClass + "\n  " + hasIconClass + " " + longParagraphClass + " " + noValueClass + " " + isFocusedClass;

  var attrs = _extends({
    className: className,
    onFocus: onFocus,
    value: value,
    disabled: disabled
  }, props);

  var handleBlur = function handleBlur(event) {
    if (!isWithError) {
      setIsWithError(isCharacterLimitError);
    }

    onBlur(event);
    setIsFocused(false);
  };

  var handleFocus = function handleFocus(event) {
    setIsWithError(status === 'error');
    onFocus(event);
    setIsFocused(true);
  };

  return React.createElement(Container, {
    containerWidth: containerWidth
  }, React.createElement(InputWrapper, {
    className: wrapperClassname
  }, prefix && React.createElement(PrefixLabel, {
    ref: function ref(prefixRef) {
      return setPrefixWidth((prefixRef == null ? void 0 : prefixRef.clientWidth) || 0);
    }
  }, prefix), React.createElement(InputContainer, null, longParagraph ? React.createElement(TextareaStyle, Object.assign({}, attrs, {
    onBlur: function onBlur(e) {
      return handleBlur(e);
    },
    onFocus: function onFocus(e) {
      return handleFocus(e);
    },
    placeholder: isFocused ? placeholder : ''
  })) : React.createElement(InputStyle, Object.assign({}, attrs, {
    onBlur: function onBlur(e) {
      return handleBlur(e);
    },
    onFocus: function onFocus(e) {
      return handleFocus(e);
    },
    placeholder: isFocused ? placeholder : ''
  })), label && React.createElement(SubLabel, {
    className: required + " " + sizeClass + " " + isFocusedClass + " " + hasValueClass + " " + isWithErrorClass,
    prefixWidth: prefixWidth,
    htmlFor: id
  }, label)), React.createElement(SuffixWrapper, {
    longParagraph: longParagraph
  }, status === 'error' && React.createElement(ErrorIcon, null, React.createElement(Icon, {
    name: "alert-circle"
  })), icon && React.createElement(IconWrapper, {
    className: "icon"
  }, typeof icon === "string" ? React.createElement(Icon, {
    name: icon
  }) : icon), suffix && React.createElement(SuffixLabel, {
    className: "ml-2 text-right"
  }, suffix))), React.createElement(ParagraphWrapper, {
    className: wrapperClassname
  }, React.createElement("span", {
    className: "assitiveText"
  }, assitiveText), React.createElement("span", {
    className: "characterLimit"
  }, characterLimit > 0 && React.createElement(React.Fragment, null, value.toString().length, "/", characterLimit, " characters"))));
};

var _templateObject$5, _templateObject2$4, _templateObject3$3, _templateObject4$3, _templateObject5$3, _templateObject6$2, _templateObject7$2, _templateObject8$2, _templateObject9$1, _templateObject10$1, _templateObject11$1, _templateObject12$1, _templateObject13, _templateObject14, _templateObject15, _templateObject16;
var colors$8 = theme.colors,
    fonts$4 = theme.fonts;
var Container$1 = /*#__PURE__*/styled.div(_templateObject$5 || (_templateObject$5 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  position: relative;\n"])));
var DropdownWrapper = /*#__PURE__*/styled.div(_templateObject2$4 || (_templateObject2$4 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: 100%;\n\n  .icon > svg {\n    color: ", ";\n    font-size: 10px;\n  }\n\n  &.isOpen .icon > svg {\n    transform: rotateX(180deg);\n  }\n"])), colors$8.gray700);
var ListBox = /*#__PURE__*/styled.div(_templateObject3$3 || (_templateObject3$3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  position: absolute;\n  display: flex;\n  flex-direction: column;\n  background-color: ", ";\n  pointer-events: auto;\n  visibility: visible;\n  margin-top: -4px;\n  border: 1px solid rgba(0, 0, 0, 0.08);\n  box-shadow: 0 8px 8px rgba(0, 0, 0, 0.15);\n  width: fit-content;\n  min-width: ", ";\n  z-index: 999;\n  font-family: ", ";\n\n  &.multiSelect {\n    padding: 0 0 3.25rem;\n    &.isMobileIOS {\n      padding: 0 0 5.4rem;\n    }\n  }\n\n  &.hidden {\n    padding: 0;\n    pointer-events: none;\n    visibility: hidden;\n    height: 0;\n  }\n\n  &.assitiveText {\n    margin-top: -1.5rem;\n  }\n\n  &.isMobile {\n    position: fixed;\n    width: 100%;\n    height: 100%;\n    top: 0;\n    left: 0;\n\n    &.isMobileIOS {\n      height: auto;\n      max-height:94%;\n      top: auto;\n      bottom: 0;\n      border-radius: 10px 10px 0 0;\n    }\n  }\n"])), colors$8.white, function (_ref) {
  var minWidth = _ref.minWidth;
  return minWidth + "px";
}, fonts$4.body);
var ListBoxMobileHeader = /*#__PURE__*/styled.div(_templateObject4$3 || (_templateObject4$3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  font-size: 1.35rem;\n  line-height: 1.63rem;\n  padding: 1.1rem;\n  color: ", ";\n  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3), 0 2px 6px 2px rgba(0, 0, 0, 0.15);\n  margin-bottom: 0.5rem;\n  background-color: ", ";\n  z-index: 999;\n\n  &.isMobileIOS {\n    box-shadow: none;\n    display: flex;\n    justify-content: center;\n    padding: 0.7rem 4rem;\n    align-items: center;\n    margin-bottom: 0;\n    border-radius: 10px 10px 0 0;\n  }\n"])), colors$8.gray500, colors$8.white);
var LabelTitle = /*#__PURE__*/styled.span(_templateObject5$3 || (_templateObject5$3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  &.isMobileIOS {\n    font-size: 1.1rem;\n    color: ", ";\n  }\n"])), colors$8.black);
var ButtonReset = /*#__PURE__*/styled.button(_templateObject6$2 || (_templateObject6$2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  padding: 1rem 0.5rem;\n  background-color: transparent;\n  color: ", ";\n  outline: none;\n  line-height: 1.5rem;\n  font-size: 1.07rem;\n  position: absolute;\n  right: 0;\n"])), colors$8.secondary);
var ArrowBackButton = /*#__PURE__*/styled.button(_templateObject7$2 || (_templateObject7$2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  outline: none;\n  border: none;\n  background-color: transparent;\n  padding-right: 1.25rem;\n  svg {\n    font-size: 1rem;\n    color: ", ";\n  }\n"])), colors$8.gray500);
var ListBoxListContainer = /*#__PURE__*/styled.div(_templateObject8$2 || (_templateObject8$2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: column;\n  width: 100%;\n  border: 1px solid #00000014;\n  overflow-y: auto;\n  z-index: 9;\n  overflow-x: hidden;\n  background-color: ", ";\n\n  max-height: ", ";\n\n  &.isMobile {\n    max-height: 100%;\n    border: 0;\n  }\n"])), colors$8.white, function (_ref2) {
  var heightType = _ref2.heightType;
  var maxHeight = '15.5rem';

  if (heightType !== 'short') {
    maxHeight = heightType === 'tall' ? '30.5rem' : '31.8rem';
  }

  return maxHeight;
});
var ListItem = /*#__PURE__*/styled.div(_templateObject9$1 || (_templateObject9$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  position: relative;\n  display: flex;\n  align-items: center;\n  font-size: 1rem;\n  line-height: 1.5rem;\n  color: ", ";\n  padding: 0.75rem 1.1rem 0.75rem 0.75rem ;\n  justify-content: space-between;\n  cursor: pointer;\n  min-width: 100%;\n  max-width: 30vw;\n\n  span {\n    white-space: nowrap;\n    overflow: hidden;\n    text-overflow: ellipsis;\n  }\n\n  &:hover, &.selectedItem, &:hover.multiSelect {\n    background-color: ", ";\n    color: ", ";\n  }\n\n  &.multiSelect {\n    justify-content: start;\n    &.isMobileIOS {\n      justify-content: space-between;\n    }\n  }\n\n  &.multiSelect.selectedItem {\n    background-color: transparent;\n    color: ", ";\n    &.isMobile {\n      color: ", ";\n    }\n  }\n  &:hover.multiSelect {\n    background-color: ", ";\n    color: ", ";\n    &.selectedItem {\n      color: ", ";\n    }\n    &.isMobile {\n      color: ", ";\n      background-color: transparent;\n      &.selectedItem {\n        color: ", ";\n      }\n    }\n  }\n\n  &:hover.isMobile {\n    color: ", ";\n  }\n\n  &.isMobileIOS {\n    font-size: 1.065rem;\n    line-height: 1.3rem;\n\n    &:hover, &.selectedItem {\n      color: ", ";\n      background-color: transparent;\n    }\n  }\n"])), colors$8.gray700, colors$8.secondary400, colors$8.white, colors$8.gray700, colors$8.secondary, colors$8.secondary400, colors$8.white, colors$8.secondary, colors$8.gray700, colors$8.secondary, colors$8.gray700, colors$8.secondary);
var LineBottom = /*#__PURE__*/styled.span(_templateObject10$1 || (_templateObject10$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  height: 0.5px;\n  bottom: 0;\n  position: absolute;\n  width: 100%;\n  background-color: ", ";\n\n"])), colors$8.gray400);
var IconWrapper$1 = /*#__PURE__*/styled.div(_templateObject11$1 || (_templateObject11$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  align-items: center;\n  width: 1.1rem;\n  margin-left: 1.1rem;\n\n  svg {\n    width: 1rem;\n    height: 1rem;\n    color: ", ";\n  }\n\n  &.selectedItem.isMobileIOS > svg {\n    color: ", ";\n  }\n"])), colors$8.white, colors$8.secondary);
var CheckboxWrapper = /*#__PURE__*/styled.span(_templateObject12$1 || (_templateObject12$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  padding-right: 1.1rem;\n  min-width: 40px;\n  pointer-events: none;\n"])));
var ButtonFooter = /*#__PURE__*/styled.div(_templateObject13 || (_templateObject13 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  justify-content: end;\n  align-items: center;\n  position: absolute;\n  bottom: 0;\n  height: 3.25rem;\n  background-color: ", ";\n  width: 100%;\n\n  &.isMobileIOS {\n    padding: 1rem 0.5rem;\n    height: 5.4rem;\n  }\n"])), colors$8.white);
var ItemButton = /*#__PURE__*/styled.button(_templateObject14 || (_templateObject14 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  font-weight: bold;\n  padding: 8px 12px;\n  background-color: transparent;\n  color: ", ";\n  outline: none;\n  font-size: 14px;\n  line-height: 20px;\n\n  &.apply-button {\n    background-color: ", ";\n    font-weight: normal;\n    width: 100%;\n    font-size: 1.25rem;\n    line-height: 1.5rem;\n    padding: 1rem;\n    border-radius: 13px;\n    color: ", ";\n  }\n"])), colors$8.text, colors$8.gray100, colors$8.secondary);
var LineButton = /*#__PURE__*/styled.div(_templateObject15 || (_templateObject15 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: 1.25rem;\n  border: 1px solid ", ";\n  transform: rotate(90deg);\n"])), colors$8.text038);
var BackgroundListBox = /*#__PURE__*/styled.div(_templateObject16 || (_templateObject16 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n  position: fixed;\n  background-color: rgba(0, 0, 0, 0.3);\n"])));

var _excluded$6 = ["className", "id", "name", "label", "value", "onClick", "onChange", "onBlur", "onFocus", "displayFn", "disabled", "required", "status", "inputRef", "options", "type", "size", "placeholder", "assitiveText"];
var DropdownSingle = function DropdownSingle(_ref) {
  var _refContainer$current;

  var id = _ref.id,
      label = _ref.label,
      value = _ref.value,
      onClick = _ref.onClick,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? noop : _ref$onChange,
      onBlur = _ref.onBlur,
      onFocus = _ref.onFocus,
      _ref$displayFn = _ref.displayFn,
      displayFn = _ref$displayFn === void 0 ? function (item) {
    return item == null ? void 0 : item.label;
  } : _ref$displayFn,
      disabled = _ref.disabled,
      required = _ref.required,
      _ref$status = _ref.status,
      status = _ref$status === void 0 ? 'default' : _ref$status,
      inputRef = _ref.inputRef,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'short' : _ref$type,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size,
      placeholder = _ref.placeholder,
      assitiveText = _ref.assitiveText,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$6);

  var defaultDropdownRef = React.useRef(null);

  var _ref2 = inputRef || defaultDropdownRef;

  var refContainer = React.useRef(null);
  var listBoxDropdownRef = React.useRef(null);

  var _React$useState = React.useState(-1),
      highlightedIndex = _React$useState[0],
      setHighlightedIndex = _React$useState[1];

  var isMobileIOS = isMobile && isIOS;
  /**
   * @type {{[key: string]: any }}
   */

  var attrs = _extends({
    onMouseDown: onClick,
    onBlur: onBlur,
    onFocus: onFocus,
    value: value,
    status: status,
    size: size,
    disabled: disabled,
    required: required,
    assitiveText: assitiveText
  }, props);

  var selectedItem = useMemo(function () {
    return options.find(function (option) {
      return option.value === value;
    }) || null;
  }, [value, options]);
  var handleChange = useCallback(function (changes) {
    var _changes$selectedItem;

    onChange(changes == null ? void 0 : (_changes$selectedItem = changes.selectedItem) == null ? void 0 : _changes$selectedItem.value);
  }, [onChange]);
  var handleHighlightedIndexChange = useCallback(function (changes) {
    setHighlightedIndex(changes.highlightedIndex);
  }, []);

  var _useCombobox = useCombobox({
    labelId: id + "-label",
    menuId: id + "-menu",
    items: options,
    selectedItem: selectedItem,
    onSelectedItemChange: handleChange,
    highlightedIndex: highlightedIndex,
    onHighlightedIndexChange: handleHighlightedIndexChange,
    itemToString: function itemToString(item) {
      return item ? displayFn(item) : '';
    }
  }),
      isOpen = _useCombobox.isOpen,
      openMenu = _useCombobox.openMenu,
      closeMenu = _useCombobox.closeMenu,
      getMenuProps = _useCombobox.getMenuProps,
      getItemProps = _useCombobox.getItemProps,
      getInputProps = _useCombobox.getInputProps,
      getComboboxProps = _useCombobox.getComboboxProps;

  var optionsRenderer = useMemo(function () {
    return options.map(function (item, index) {
      return React.createElement(ListItem, Object.assign({
        "aria-selected": highlightedIndex === index,
        className: "\n          " + (highlightedIndex === index ? 'highlighted' : '') + " \n          " + (selectedItem === item ? 'selectedItem' : '') + " \n          " + (isMobile ? 'isMobile' : '') + " \n          " + (isMobileIOS ? 'isMobileIOS' : '') + "\n        ",
        key: item.value
      }, getItemProps({
        item: item,
        index: index
      })), React.createElement("span", null, displayFn(item) || ''), React.createElement(IconWrapper$1, {
        className: (selectedItem === item ? 'selectedItem' : '') + " " + (isMobileIOS ? 'isMobileIOS' : '')
      }, selectedItem === item && React.createElement(Icon, {
        name: "check"
      })), isMobileIOS && React.createElement(LineBottom, null));
    });
  }, [options, getItemProps, highlightedIndex, isOpen, isMobile]);
  return React.createElement(Container$1, {
    ref: refContainer
  }, React.createElement(DropdownWrapper, Object.assign({}, getComboboxProps(), {
    className: "" + (isOpen ? 'isOpen' : '')
  }), React.createElement(Input, Object.assign({}, attrs, getInputProps({
    ref: function ref(event) {
      _ref2.current = event;
    },
    refKey: 'inputRef',
    disabled: disabled,
    onFocus: function onFocus() {
      return !isOpen && openMenu();
    },
    onClick: function onClick() {
      return !isOpen && openMenu();
    }
  }), {
    icon: React.createElement(Icon, {
      name: "arrow-down-fill",
      className: "cursorPointer",
      onClick: function onClick() {
        return isOpen ? closeMenu() : openMenu();
      }
    }),
    label: label,
    placeholder: placeholder,
    value: displayFn(selectedItem),
    type: "dropdown",
    longParagraph: false
  }))), React.createElement(ListBox, Object.assign({}, getMenuProps(), {
    isOpen: isOpen,
    className: "\n          " + (!isOpen ? 'hidden' : '') + " \n          " + (assitiveText ? 'assitiveText' : '') + " \n          " + (isMobile ? 'isMobile' : '') + " \n          " + (isMobileIOS ? 'isMobileIOS' : '') + "\n         ",
    minWidth: refContainer == null ? void 0 : (_refContainer$current = refContainer.current) == null ? void 0 : _refContainer$current.clientWidth,
    heightType: type
  }), isOpen && React.createElement(React.Fragment, null, isMobileIOS && React.createElement(BackgroundListBox, null), isMobile && React.createElement(ListBoxMobileHeader, {
    className: "" + (isMobileIOS ? 'isMobileIOS' : '')
  }, !isMobileIOS && React.createElement(ArrowBackButton, {
    "aria-label": "Exit dropdown",
    onClick: closeMenu,
    type: "button"
  }, React.createElement(Icon, {
    name: "arrow-left"
  })), React.createElement(LabelTitle, {
    className: "" + (isMobileIOS ? 'isMobileIOS' : '')
  }, label)), React.createElement(ListBoxListContainer, {
    ref: listBoxDropdownRef,
    heightType: type,
    className: (isMobile ? 'isMobile' : '') + " " + (isMobileIOS ? 'isMobileIOS' : '')
  }, optionsRenderer))));
};

var _excluded$7 = ["className", "id", "label", "value", "onClick", "onChange", "onBlur", "onFocus", "displayFn", "disabled", "required", "status", "inputRef", "options", "type", "size", "placeholder", "assitiveText"];
var DropdownMulti = function DropdownMulti(_ref) {
  var _refContainer$current;

  var id = _ref.id,
      label = _ref.label,
      value = _ref.value,
      onClick = _ref.onClick,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? noop : _ref$onChange,
      onBlur = _ref.onBlur,
      onFocus = _ref.onFocus,
      _ref$displayFn = _ref.displayFn,
      displayFn = _ref$displayFn === void 0 ? function (item) {
    return item == null ? void 0 : item.label;
  } : _ref$displayFn,
      disabled = _ref.disabled,
      required = _ref.required,
      _ref$status = _ref.status,
      status = _ref$status === void 0 ? 'default' : _ref$status,
      inputRef = _ref.inputRef,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'short' : _ref$type,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size,
      placeholder = _ref.placeholder,
      assitiveText = _ref.assitiveText,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$7);

  var defaultDropdownRef = React.useRef(null);

  var _ref2 = inputRef || defaultDropdownRef;

  var refContainer = React.useRef(null);
  var listBoxDropdownRef = React.useRef(null);
  var isMobileIOS = isMobile && isIOS;

  var attrs = _extends({
    onMouseDown: onClick,
    onBlur: onBlur,
    onFocus: onFocus,
    status: status,
    size: size,
    disabled: disabled,
    required: required,
    assitiveText: assitiveText
  }, props);

  var selectedItem = useMemo(function () {
    var values = value || []; // @ts-ignore

    return (options == null ? void 0 : options.filter(function (option) {
      return values == null ? void 0 : values.includes(option == null ? void 0 : option.value);
    })) || [];
  }, [value, options]);
  var handleChange = useCallback(function (changes) {
    var _changes$selectedItem;

    // @ts-ignore
    var values = value;
    var selectedItemValue = changes == null ? void 0 : (_changes$selectedItem = changes.selectedItem) == null ? void 0 : _changes$selectedItem.value;
    var isExist = values == null ? void 0 : values.includes(selectedItemValue);
    var data = [].concat(values, [selectedItemValue]);

    if (isExist) {
      data = (values == null ? void 0 : values.filter(function (item) {
        return item !== selectedItemValue;
      })) || [];
    } // @ts-ignore


    onChange(data);
  }, [onChange]); // @ts-ignore

  var handleClear = function handleClear() {
    return onChange([]);
  }; // @ts-ignore


  var handleSelectAll = function handleSelectAll() {
    return onChange(options.map(function (option) {
      return option == null ? void 0 : option.value;
    }));
  };

  var _useCombobox = useCombobox({
    labelId: id + "-label",
    menuId: id + "-menu",
    items: options,
    // @ts-ignore
    selectedItem: selectedItem,
    onSelectedItemChange: handleChange,
    // @ts-ignore
    itemToString: function itemToString(item) {
      return item && displayFn ? displayFn(item) : '';
    },
    stateReducer: function stateReducer(_state, actionAndChanges) {
      var changes = actionAndChanges.changes;

      switch (actionAndChanges == null ? void 0 : actionAndChanges.type) {
        case useCombobox.stateChangeTypes.InputKeyDownEnter:
        case useCombobox.stateChangeTypes.ItemClick:
          {
            return _extends({}, changes, {
              isOpen: !!changes.selectedItem
            });
          }

        default:
          return changes;
      }
    }
  }),
      isOpen = _useCombobox.isOpen,
      openMenu = _useCombobox.openMenu,
      closeMenu = _useCombobox.closeMenu,
      getMenuProps = _useCombobox.getMenuProps,
      getItemProps = _useCombobox.getItemProps,
      getInputProps = _useCombobox.getInputProps,
      getComboboxProps = _useCombobox.getComboboxProps;

  var optionsRenderer = useMemo(function () {
    return options.map(function (item, index) {
      var values = value; // @ts-ignore

      var isSelectedItem = values.includes(item == null ? void 0 : item.value);
      return React.createElement(ListItem, Object.assign({
        className: "\n            multiSelect\n            " + (isSelectedItem ? 'selectedItem' : '') + " \n            " + (isMobile ? 'isMobile' : '') + " \n            " + (isMobileIOS ? 'isMobileIOS' : '') + "\n          ",
        key: item == null ? void 0 : item.value
      }, getItemProps({
        item: item,
        index: index
      })), !isMobileIOS && React.createElement(CheckboxWrapper, null, React.createElement(Checkbox, {
        checked: selectedItem.includes(item)
      })), React.createElement("span", null, displayFn(item) || ''), isMobileIOS && React.createElement(React.Fragment, null, React.createElement(IconWrapper$1, {
        className: "multiSelect " + (isSelectedItem ? 'selectedItem' : '') + " " + (isMobileIOS ? 'isMobileIOS' : '')
      }, selectedItem.includes(item) && React.createElement(Icon, {
        name: "check"
      })), React.createElement(LineBottom, null)));
    });
  }, [value, options, getItemProps, isOpen, isMobile]);
  return React.createElement(Container$1, {
    ref: refContainer
  }, React.createElement(DropdownWrapper, Object.assign({}, getComboboxProps(), {
    className: "" + (isOpen ? 'isOpen' : '')
  }), React.createElement(Input, Object.assign({}, attrs, getInputProps({
    ref: function ref(event) {
      _ref2.current = event;
    },
    refKey: 'inputRef',
    disabled: disabled,
    onFocus: function onFocus() {
      return !isOpen && openMenu();
    },
    onClick: function onClick() {
      return !isOpen && openMenu();
    }
  }), {
    icon: React.createElement(Icon, {
      name: "arrow-down-fill",
      className: "cursorPointer",
      onClick: function onClick() {
        return isOpen ? closeMenu() : openMenu();
      }
    }),
    label: label,
    placeholder: placeholder,
    value: "Selected (" + (value == null ? void 0 : value.length) + ") " + label,
    type: "dropdown",
    longParagraph: false
  }))), React.createElement(ListBox, Object.assign({}, getMenuProps(), {
    isOpen: isOpen,
    className: " multiSelect " + (!isOpen ? 'hidden' : '') + " " + (assitiveText ? 'assitiveText' : '') + "  " + (isMobile ? 'isMobile' : '') + " " + (isMobileIOS ? 'isMobileIOS' : ''),
    minWidth: refContainer == null ? void 0 : (_refContainer$current = refContainer.current) == null ? void 0 : _refContainer$current.clientWidth,
    heightType: type
  }), isOpen && React.createElement(React.Fragment, null, isMobileIOS && React.createElement(BackgroundListBox, null), isMobile && React.createElement(ListBoxMobileHeader, {
    className: "" + (isMobileIOS ? 'isMobileIOS' : '')
  }, !isMobileIOS && React.createElement(ArrowBackButton, {
    "aria-label": "Exit dropdown",
    onClick: closeMenu,
    type: "button"
  }, React.createElement(Icon, {
    name: "arrow-left"
  })), React.createElement(LabelTitle, {
    className: "" + (isMobileIOS ? 'isMobileIOS' : '')
  }, label), isMobileIOS && React.createElement(ButtonReset, {
    onClick: function onClick() {
      return handleClear();
    }
  }, "Reset")), React.createElement(ListBoxListContainer, {
    ref: listBoxDropdownRef,
    heightType: type,
    className: (isMobile ? 'isMobile' : '') + " " + (isMobileIOS ? 'isMobileIOS' : '')
  }, optionsRenderer), React.createElement(ButtonFooter, {
    className: cx(isMobileIOS && 'isMobileIOS')
  }, React.createElement(ItemButton, {
    className: cx(isMobileIOS && 'hidden'),
    onClick: function onClick() {
      return handleClear();
    }
  }, "CLEAR"), React.createElement(LineButton, {
    className: cx(isMobileIOS && 'hidden')
  }), React.createElement(ItemButton, {
    className: cx(isMobileIOS && 'hidden'),
    onClick: function onClick() {
      return handleSelectAll();
    }
  }, "SELECT ALL"), React.createElement(ItemButton, {
    className: cx('apply-button', isMobileIOS ? 'show' : 'hidden'),
    onClick: function onClick() {
      return closeMenu();
    }
  }, "Apply")))));
};

var _excluded$8 = ["label", "inputRef", "value", "onClick", "onChange", "onBlur", "onFocus", "displayFn", "disabled", "required", "status", "options", "multiSelect", "type", "size", "assitiveText"];
var Dropdown = function Dropdown(_ref) {
  var _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      _ref$inputRef = _ref.inputRef,
      inputRef = _ref$inputRef === void 0 ? null : _ref$inputRef,
      value = _ref.value,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? noop : _ref$onClick,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? noop : _ref$onChange,
      _ref$onBlur = _ref.onBlur,
      onBlur = _ref$onBlur === void 0 ? noop : _ref$onBlur,
      _ref$onFocus = _ref.onFocus,
      onFocus = _ref$onFocus === void 0 ? noop : _ref$onFocus,
      _ref$displayFn = _ref.displayFn,
      displayFn = _ref$displayFn === void 0 ? function (item) {
    return item == null ? void 0 : item.label;
  } : _ref$displayFn,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$required = _ref.required,
      required = _ref$required === void 0 ? false : _ref$required,
      _ref$status = _ref.status,
      status = _ref$status === void 0 ? 'default' : _ref$status,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options,
      _ref$multiSelect = _ref.multiSelect,
      multiSelect = _ref$multiSelect === void 0 ? false : _ref$multiSelect,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'short' : _ref$type,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size,
      _ref$assitiveText = _ref.assitiveText,
      assitiveText = _ref$assitiveText === void 0 ? '' : _ref$assitiveText,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$8);

  /**
   * @type {{[key: string]: any }}
   */
  var attrs = _extends({
    label: label,
    value: value,
    onClick: onClick,
    onChange: onChange,
    onBlur: onBlur,
    onFocus: onFocus,
    displayFn: displayFn,
    disabled: disabled,
    required: required,
    status: status,
    inputRef: inputRef,
    options: options,
    type: type,
    size: size,
    assitiveText: assitiveText,
    readOnly: true
  }, props);

  return multiSelect ? React.createElement(DropdownMulti, Object.assign({}, attrs)) : React.createElement(DropdownSingle, Object.assign({}, attrs));
};

var _templateObject$6, _templateObject2$5, _templateObject3$4, _templateObject4$4;
var colors$9 = theme.colors;
var InfoboxContainer = /*#__PURE__*/styled.div(_templateObject$6 || (_templateObject$6 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  padding: 1rem;\n  border-radius: 4px;\n  background: ", ";\n  width: auto;\n\n  &.isHighEmphasis {\n    border-width: 1px;\n    border-style: solid;\n    border-color: ", ";\n  }\n\n  button {\n    margin-left: 10px;\n    min-width: 10.6rem;\n    align-self: center;\n    justify-content: center;\n    text-transform: uppercase;\n  }\n\n  &.isMobile button {\n    width: 100%;\n    margin: 12px 0 0;\n    text-transform: capitalize;\n  }\n\n  &.green {\n    border-color: ", ";\n  }\n\n  &.red {\n    border-color: ", ";\n    background: ", ";\n  }\n\n  &.neutral {\n    background: #FDFCF7;\n    border-color: ", ";\n  }\n"])), colors$9.green50, colors$9.green50, colors$9.green, colors$9.primary900, colors$9.primary50, colors$9.gray300);
var InfoWrapper = /*#__PURE__*/styled.div(_templateObject2$5 || (_templateObject2$5 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: row;\n\n  &.isMobile {\n    flex-flow: wrap;\n  }\n"])));
var IconWrapper$2 = /*#__PURE__*/styled.div(_templateObject3$4 || (_templateObject3$4 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  margin-right: 14px;\n  color: ", ";\n  svg {\n    font-size: 20px;\n  }\n\n  &.red {\n    color: ", ";\n  }\n\n  &.neutral {\n    color: ", ";\n  }\n"])), colors$9.green, colors$9.primary900, colors$9.gray700);
var ContextWrapper$2 = /*#__PURE__*/styled.div(_templateObject4$4 || (_templateObject4$4 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: column;\n  color: ", ";\n  line-height: 22px;\n  text-align: start;\n\n  .title {\n    font-weight: 700;\n    font-size: 1rem;\n    margin-bottom: 4px;\n\n    &.isIOS {\n      font-weight: 600;\n      font-size: 1.1rem;\n    }\n  }\n\n  .description {\n    font-size: 14px;\n    &.isIOS {\n      line-height: 21px;\n    }\n  }\n"])), colors$9.text);

var _excluded$9 = ["id", "title", "description", "color", "className", "isHighEmphasis", "isButton", "buttonLabel", "onClick", "icon"];
var Infobox = function Infobox(_ref) {
  var id = _ref.id,
      title = _ref.title,
      description = _ref.description,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'green' : _ref$color,
      className = _ref.className,
      isHighEmphasis = _ref.isHighEmphasis,
      isButton = _ref.isButton,
      _ref$buttonLabel = _ref.buttonLabel,
      buttonLabel = _ref$buttonLabel === void 0 ? 'cta' : _ref$buttonLabel,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? noop : _ref$onClick,
      icon = _ref.icon,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$9);

  var attrs = _extends({
    id: id
  }, props);

  var infoBoxClasses = cx(className, color, isMobile && 'isMobile', isHighEmphasis && 'isHighEmphasis');

  var handleClick = function handleClick(e) {
    onClick(e);
  };

  return React.createElement(InfoboxContainer, Object.assign({}, attrs, {
    className: infoBoxClasses
  }), icon && React.createElement(IconWrapper$2, {
    className: cx(color)
  }, typeof icon === "string" ? React.createElement(Icon, {
    name: icon
  }) : icon), React.createElement(InfoWrapper, {
    className: cx(isMobile && 'isMobile')
  }, React.createElement(ContextWrapper$2, null, React.createElement("span", {
    className: cx('title', isIOS && 'isIOS')
  }, title), React.createElement("span", {
    className: cx('description', isIOS && 'isIOS')
  }, description)), isButton && React.createElement(Button, {
    color: color === 'green' ? 'secondary' : 'primary',
    onClick: handleClick
  }, buttonLabel)));
};

var _templateObject$7, _templateObject2$6, _templateObject3$5, _templateObject4$5, _templateObject5$4, _templateObject6$3, _templateObject7$3, _templateObject8$3;
var colors$a = theme.colors,
    radii$3 = theme.radii,
    sizes$4 = theme.sizes,
    zIndices$2 = theme.zIndices,
    fonts$5 = theme.fonts;
var Modal$1 = /*#__PURE__*/styled.div(_templateObject$7 || (_templateObject$7 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: grid;\n  place-items: center;\n  position: fixed;\n  top: 0;\n  left: 0;\n  width: ", ";\n  height: ", ";\n  padding: 0.75rem;\n  z-index: ", ";\n  font-family: ", ";\n\n  &.isMobile {\n    padding: 0;\n  }\n"])), sizes$4.vW, sizes$4.vH, zIndices$2.modal, fonts$5.body);
var Backdrop$1 = /*#__PURE__*/styled.div(_templateObject2$6 || (_templateObject2$6 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  background-color: ", ";\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: ", ";\n  height: ", ";\n  opacity: 0.3;\n"])), colors$a.black, sizes$4.full, sizes$4.full);
var StyledPopup = /*#__PURE__*/styled.div(_templateObject3$5 || (_templateObject3$5 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: fit-content;\n  overflow-x: hidden;\n  overflow-y: auto;\n  box-shadow: 0 12px 36px rgba(0, 0, 0, 0.25);\n  z-index: ", ";\n  background-color: ", ";\n  border-radius: ", ";\n  max-height: 35rem;\n  ", "\n\n  &.isMobile {\n    width: 100%;\n    height: 100%;\n    max-height: 100%;\n    border-radius: 0;\n  }\n"])), zIndices$2.up, colors$a.white, radii$3.sm, function (_ref) {
  var maxWidth = _ref.maxWidth;
  return maxWidth ? "max-width:" + maxWidth + ";" : '';
});
var StyledHeader = /*#__PURE__*/styled.div(_templateObject4$5 || (_templateObject4$5 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  align-items: center;\n  padding: 1.5rem 1rem 1rem 2rem;\n  justify-content: space-between;\n  background-color: ", ";\n\n  &.isSticky {\n    top: 0;\n    position: sticky;\n    z-index: ", ";\n    box-shadow: 0 4px 6px rgba(0, 0, 0, 0.15);\n  }\n\n\n  .title {\n    font-weight: 600;\n    font-size: 1.25rem;\n    line-height: 1.75rem;\n    color: ", ";\n  }\n\n  .closeButton {\n    padding: 0;\n    width: 1.5rem;\n    height: 1.5rem;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    background: transparent;\n    margin-left: 1rem;\n\n    &:focus {\n      outline: none;\n    }\n    svg {\n      font-size: 14px;\n    }\n  }\n\n  &.isCloseButtonLeft.isMobile,\n  &.isIOS {\n    justify-content: flex-end;\n    flex-flow: row-reverse;\n    .closeButton {\n      margin-left: 0;\n      margin-right: 1rem;\n    }\n  }\n\n  &.isMobile {\n    padding: 1rem 1rem 0.75rem 1rem;\n\n    &.isIOS {\n      padding: 9px 1rem 11px 1rem;\n      .title {\n        font-size: 17px;\n        font-weight: 700;\n        line-height: 1.38rem;\n      }\n    }\n  }\n\n  &.hasImage {\n    padding-top: 1rem;\n  }\n"])), colors$a.white, zIndices$2.up, colors$a.black);
var ContextWrapper$3 = /*#__PURE__*/styled.div(_templateObject5$4 || (_templateObject5$4 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  position: relative;\n  width: ", ";\n"])), sizes$4.full);
var Image$1 = /*#__PURE__*/styled.img(_templateObject6$3 || (_templateObject6$3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: 100%;\n  object-fit: cover;\n  margin-bottom: 1rem;\n\n  &.isMobile {\n    margin-bottom: 0.5rem;\n  }\n"])));
var ChildrenWrapper$1 = /*#__PURE__*/styled.div(_templateObject7$3 || (_templateObject7$3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  overflow-y: hidden;\n  color: ", ";\n  font-weight: 400;\n  font-size: 14px;\n  line-height: 22px;\n  padding: 0 2rem 1.5rem ;\n\n  &.is-single-string {\n    white-space: pre-wrap;\n  }\n\n  &.isMobile {\n    padding: 0 1rem;\n  }\n\n  &.isIOS {\n    font-size: 13px;\n    line-height: 18px;\n    text-align: center;\n    letter-spacing: -0.078px;\n  }\n"])), colors$a.text060);
var ButtonWrapper$1 = /*#__PURE__*/styled.div(_templateObject8$3 || (_templateObject8$3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: row-reverse;\n  background-color: ", ";\n  border-top: 1px solid rgba(0, 0, 0, 0.08);\n  padding: 1.5rem 2rem;\n  position: sticky;\n  bottom: 0;\n\n  button{\n    margin-left: 4px;\n    text-transform: uppercase;\n  }\n\n  .buttonAction2, .buttonAction3 {\n    color: ", ";\n  }\n\n  &.isMobileVertical {\n    flex-wrap: wrap;\n    align-items: center;\n    flex-direction: column;\n    padding: 0 1rem;\n\n    button {\n      width: 100%;\n      margin-left: 0;\n      margin-top: 0.75rem;\n      text-align: center;\n      justify-content: center;\n    }\n  }\n\n  &.isMobile {\n    padding: 1rem;\n    width: 100%;\n\n    &:not(.hasScrollbar) {\n      position: fixed;\n    }\n  }\n\n  &.isIOS {\n    padding: 0.5rem;\n    button{\n      text-transform: capitalize;\n    }\n  }\n"])), colors$a.white, colors$a.text);

var _excluded$a = ["maxWidth", "image", "title", "className", "children", "btnLabel1", "btnLabel2", "btnLabel3", "open", "isMobileVertical", "isCloseButtonLeft", "onClose", "onButtonClick1", "onButtonClick2", "onButtonClick3"];
var Popup = function Popup(_ref) {
  var maxWidth = _ref.maxWidth,
      _ref$image = _ref.image,
      image = _ref$image === void 0 ? null : _ref$image,
      _ref$title = _ref.title,
      title = _ref$title === void 0 ? '' : _ref$title,
      className = _ref.className,
      children = _ref.children,
      _ref$btnLabel = _ref.btnLabel1,
      btnLabel1 = _ref$btnLabel === void 0 ? 'confirm' : _ref$btnLabel,
      _ref$btnLabel2 = _ref.btnLabel2,
      btnLabel2 = _ref$btnLabel2 === void 0 ? 'cancel' : _ref$btnLabel2,
      _ref$btnLabel3 = _ref.btnLabel3,
      btnLabel3 = _ref$btnLabel3 === void 0 ? '' : _ref$btnLabel3,
      _ref$open = _ref.open,
      open = _ref$open === void 0 ? false : _ref$open,
      _ref$isMobileVertical = _ref.isMobileVertical,
      isMobileVertical = _ref$isMobileVertical === void 0 ? false : _ref$isMobileVertical,
      _ref$isCloseButtonLef = _ref.isCloseButtonLeft,
      isCloseButtonLeft = _ref$isCloseButtonLef === void 0 ? false : _ref$isCloseButtonLef,
      _ref$onClose = _ref.onClose,
      onClose = _ref$onClose === void 0 ? noop : _ref$onClose,
      _ref$onButtonClick = _ref.onButtonClick1,
      onButtonClick1 = _ref$onButtonClick === void 0 ? noop : _ref$onButtonClick,
      _ref$onButtonClick2 = _ref.onButtonClick2,
      onButtonClick2 = _ref$onButtonClick2 === void 0 ? noop : _ref$onButtonClick2,
      _ref$onButtonClick3 = _ref.onButtonClick3,
      onButtonClick3 = _ref$onButtonClick3 === void 0 ? noop : _ref$onButtonClick3,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$a);

  var refPopup = useRef(null);

  var _useState = useState(false),
      hasScrollbar = _useState[0],
      setHasScrollbar = _useState[1];

  var _useState2 = useState(false),
      isSticky = _useState2[0],
      setIsSticky = _useState2[1];

  var childrenWrapperClasses = cx((typeof children === 'string' || typeof children === 'number') && 'is-single-string', isMobile && 'isMobile');

  var handleSticky = function handleSticky() {
    var _refPopup$current, _document$querySelect, _document$querySelect2, _document$querySelect3, _document$querySelect4, _document$querySelect5, _document$querySelect6;

    var offsetTop = ((_refPopup$current = refPopup.current) == null ? void 0 : _refPopup$current.offsetTop) || 0;
    var scrollTop = ((_document$querySelect = document.querySelector('.popupContext')) == null ? void 0 : (_document$querySelect2 = _document$querySelect.getClientRects()) == null ? void 0 : (_document$querySelect3 = _document$querySelect2[0]) == null ? void 0 : _document$querySelect3.top) || 0;
    var headerHeight = ((_document$querySelect4 = document.querySelector('.popupHeader')) == null ? void 0 : (_document$querySelect5 = _document$querySelect4.getClientRects()) == null ? void 0 : (_document$querySelect6 = _document$querySelect5[0]) == null ? void 0 : _document$querySelect6.height) || 0;
    setIsSticky(scrollTop - (offsetTop + headerHeight) < -2);
  };

  useEffect(function () {
    if (refPopup.current !== null) {
      var isScrollbar = refPopup.current.scrollHeight > refPopup.current.clientHeight;
      setHasScrollbar(isScrollbar);

      if (open) {
        refPopup.current.addEventListener('scroll', handleSticky);
      } else {
        refPopup.current.removeEventListener('scroll', handleSticky);
      }
    }
  }, [open]);
  return React.createElement("div", null, open && createUniversalPortal(React.createElement(Modal$1, {
    className: cx(isMobile && 'isMobile')
  }, React.createElement(Backdrop$1, null), React.createElement(StyledPopup, Object.assign({
    maxWidth: maxWidth
  }, props, {
    ref: refPopup,
    className: cx(className, isMobile && 'isMobile', isIOS && 'isIOS')
  }), React.createElement(StyledHeader, {
    className: cx('popupHeader', isSticky && 'isSticky', isMobile && 'isMobile', isIOS && 'isIOS', isCloseButtonLeft && 'isCloseButtonLeft')
  }, title && React.createElement("div", {
    className: "title"
  }, title), React.createElement("button", {
    className: "closeButton",
    type: "button",
    onClick: onClose
  }, React.createElement(Icon, {
    name: "close"
  }))), React.createElement(ContextWrapper$3, {
    className: cx('popupContext', image && 'hasImage', isMobile && 'isMobile', isIOS && 'isIOS')
  }, image && (typeof image === 'string' ? React.createElement(Image$1, {
    className: cx('image', isMobile && 'isMobile'),
    src: image,
    alt: "image"
  }) : image), React.createElement(ChildrenWrapper$1, {
    className: childrenWrapperClasses
  }, children)), React.createElement(ButtonWrapper$1, {
    className: cx(isMobile && 'isMobile', isMobileVertical && isMobile && 'isMobileVertical', isIOS && 'isIOS', hasScrollbar && 'hasScrollbar')
  }, btnLabel1 && (typeof btnLabel1 === "string" ? React.createElement(Button, {
    styles: "btn-pri-low",
    className: "buttonAction1",
    onClick: onButtonClick1
  }, btnLabel1) : btnLabel1), btnLabel2 && (typeof btnLabel2 === "string" ? React.createElement(Button, {
    styles: "btn-net-low",
    className: "buttonAction2",
    onClick: onButtonClick2
  }, btnLabel2) : btnLabel2), btnLabel3 && (typeof btnLabel3 === "string" ? React.createElement(Button, {
    styles: "btn-net-low",
    className: "buttonAction3",
    onClick: onButtonClick3
  }, btnLabel3) : btnLabel3))))));
};

var _templateObject$8, _templateObject2$7, _templateObject3$6;
var colors$b = theme.colors;
var StepperContainer = /*#__PURE__*/styled.div(_templateObject$8 || (_templateObject$8 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  align-items: center;\n  user-select: none;\n"])));
/**
 * @type {React.FC<any>}
 */

var IconWrapper$3 = /*#__PURE__*/styled.span(_templateObject2$7 || (_templateObject2$7 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: contents;\n  color: ", ";\n  cursor: pointer;\n  user-select: none;\n\n  &.disabled {\n    cursor: auto;\n    color: ", ";\n    pointer-events: none;\n  }\n"])), function (_ref) {
  var colorStepper = _ref.colorStepper;
  return colorStepper;
}, colors$b.gray500);
var LabelValue = /*#__PURE__*/styled.span(_templateObject3$6 || (_templateObject3$6 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  font-weight: 700;\n  line-height: 22px;\n  font-size: 1rem;\n  margin: 0 10px;\n  display: inline-block;\n  user-select: none;\n  position: relative;\n\n  &:after {\n    position: absolute;\n    bottom: -4px;\n    left: -4px;\n    padding: 0 4px;\n    content: '';\n    width: calc(100% + 8px);\n    height: 1px;\n    background: rgba(0, 0, 0, 0.08);\n  }\n\n  &.disabled, &[disabled] {\n    color: ", ";\n  }\n"])), colors$b.gray500);

var _excluded$b = ["value", "color", "disabled", "isDisableDecrease", "isDisableIncrease", "onChange"];
var colors$c = theme.colors;
var Stepper = function Stepper(_ref) {
  var _ref$value = _ref.value,
      value = _ref$value === void 0 ? 0 : _ref$value,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'secondary' : _ref$color,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$isDisableDecreas = _ref.isDisableDecrease,
      isDisableDecrease = _ref$isDisableDecreas === void 0 ? false : _ref$isDisableDecreas,
      _ref$isDisableIncreas = _ref.isDisableIncrease,
      isDisableIncrease = _ref$isDisableIncreas === void 0 ? false : _ref$isDisableIncreas,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? noop : _ref$onChange,
      props = _objectWithoutPropertiesLoose(_ref, _excluded$b);

  var inputAttrs = _extends({
    disabled: disabled
  }, props);

  var colorStepper = (colors$c == null ? void 0 : colors$c[color]) || color || colors$c.secondary;

  var handleDecrease = function handleDecrease() {
    onChange(Number(value) - 1);
  };

  var handleIncrease = function handleIncrease() {
    onChange(Number(value) + 1);
  };

  return React.createElement(StepperContainer, null, React.createElement(IconWrapper$3, {
    onClick: handleDecrease,
    colorStepper: colorStepper,
    className: cx((disabled || isDisableDecrease) && 'disabled')
  }, React.createElement(Icon, {
    name: "minus-circle-outline"
  })), React.createElement(LabelValue, Object.assign({}, inputAttrs), value), React.createElement(IconWrapper$3, {
    onClick: handleIncrease,
    colorStepper: colorStepper,
    className: cx((disabled || isDisableIncrease) && 'disabled')
  }, React.createElement(Icon, {
    name: "add-circle-outline"
  })));
};

export { Button, Checkbox, Chip, Dialog, Dropdown, Icon, Infobox, Input, Popup, Stepper, createUniversalPortal, cx, noop };
//# sourceMappingURL=design-ui-hung1.esm.js.map
