import React from 'react';
import { isMobile, isIOS } from 'react-device-detect';

import { createUniversalPortal, noop } from '../../utils';
import { Button } from '../index';
import {
  Modal,
  Backdrop,
  StyledDialog,
  ContextWrapper,
  Image,
  ChildrenWrapper,
  ButtonWrapper,
  Separator,
} from './styles';

/**
 * Index informs users about critical information or require decisions.
 */
export type DialogProps = {
  /**
   * Index image
   */
  image?: any,
  /**
   * Index title
   */
  title?: string,
  /**
   * Index content
   */
  children?: any,
  /**
   * Index className (can be used to add more styles to mainIcon by targeting `main-icon` class in case of using a custom string)
   */
  className?: string,
  /**
   * Index button label
   */
  btnLabel1?: string,
  btnLabel2?: string,
  btnLabel3?: string,
  /**
   * Index max-width on desktop
   */
  isLargeSize?: boolean,
  /**
   * Whether this Index is open or not
   */
  open?: boolean,
  isMobileVertical?: boolean,
  /**
   * Callback when close icon is clicked. Normally, it is used to update `open` prop to close the dialog.
   */
  onClose?: React.MouseEventHandler,
  /**
   * Callback when dialog main button is clicked
   */
  onButtonClick1?: React.MouseEventHandler,
  onButtonClick2?: React.MouseEventHandler,
  onButtonClick3?: React.MouseEventHandler,
} & React.HTMLAttributes<HTMLDivElement>;

export const Dialog = (
  {
    image,
    title,
    children,
    className,
    btnLabel1 = 'confirm',
    btnLabel2 = 'cancel',
    btnLabel3,
    isLargeSize = false,
    open = false,
    isMobileVertical = false,
    onClose = noop,
    onButtonClick1 = noop,
    onButtonClick2 = noop,
    onButtonClick3 = noop,
    ...props
  }: DialogProps) => {

  const childrenWrapperClasses = (typeof children === 'string' || typeof children === 'number') ? 'is-single-string' : '';

  const isLargeSizeClass = isLargeSize ? 'isLargeSize' : '';
  const imageClass = image ? 'hasImage' : '';
  const isMobileClass = isMobile ? 'isMobile' : '';
  const isIOSClass = isIOS ? 'isIOS' : '';
  const isMobileVerticalClass = isMobileVertical && isMobile ? 'isMobileVertical' : '';


  return (
    <div>
      {open &&
        createUniversalPortal(
          <Modal { ...props}>
            <Backdrop onClick={onClose} />
            <StyledDialog className={`${className} ${isLargeSizeClass} ${isIOSClass}`}>
              {image && (
                typeof image === 'string' ?
                  <Image className="image" src={image} alt="image" /> :
                  image
              )}
              <ContextWrapper className={`${imageClass} ${isMobileClass} ${isIOSClass}`}>
                {title && (<div className="title">{title}</div>)}
                <ChildrenWrapper className={childrenWrapperClasses}>
                  {children}
                </ChildrenWrapper>
                <ButtonWrapper className={`${isMobileVerticalClass} ${isIOSClass}`}>
                  {btnLabel1 && (
                    <>
                      <Button styles="btn-pri-low" className="buttonAction1" onClick={onButtonClick1}>
                        {btnLabel1}
                      </Button>
                      {isIOS && <Separator className={`${isMobileVerticalClass} ${isIOSClass}`} />}
                    </>
                  )}
                  {btnLabel2 && (
                    <Button styles="btn-net-low" className="buttonAction2" onClick={onButtonClick2}>
                      {btnLabel2}
                    </Button>
                  )}
                  {btnLabel3 && (
                    <>
                      {isIOS && <Separator className={`${isMobileVerticalClass} ${isIOSClass}`} />}
                      <Button styles="btn-net-low" className="buttonAction3" onClick={onButtonClick3}>
                        {btnLabel3}
                      </Button>
                    </>
                  )}
                </ButtonWrapper>
              </ContextWrapper>
            </StyledDialog>
          </Modal>
        )}
    </div>
  );
};
