import React, { useCallback, useMemo } from 'react';
import { useCombobox } from 'downshift';
import { isMobile, isIOS } from 'react-device-detect';
import { Input, Icon, Checkbox, cx, noop } from '../../index';

import {
  Container,
  DropdownWrapper,
  ListBox,
  LineBottom,
  ListBoxMobileHeader,
  LabelTitle,
  ButtonReset,
  ArrowBackButton,
  ListBoxListContainer,
  ListItem,
  CheckboxWrapper,
  ButtonFooter,
  ItemButton,
  LineButton,
  IconWrapper,
  BackgroundListBox,
} from './styles';
import {DropdownProps} from "./index";

export const DropdownMulti = (
  {
    className,
    id,
    label,
    value,
    onClick,
    onChange = noop,
    onBlur,
    onFocus,
    displayFn = (item) => item?.label,
    disabled,
    required,
    status = 'default',
    inputRef,
    options = [],
    type = 'short',
    size = 'medium',
    placeholder,
    assitiveText,
    ...props
  }: DropdownProps) => {
  const defaultDropdownRef = React.useRef(null);
  const ref = inputRef || defaultDropdownRef;
  const refContainer = React.useRef<HTMLDivElement>(null);
  const listBoxDropdownRef = React.useRef(null);
  const isMobileIOS = isMobile && isIOS;
  const attrs = {
    onMouseDown: onClick,
    onBlur,
    onFocus,
    status,
    size,
    disabled,
    required,
    assitiveText,
    ...props,
  };

  const selectedItem = useMemo(() => {
    const values = value || [];
    // @ts-ignore
    return options?.filter((option) => values?.includes(option?.value)) || []
  }, [value, options]);

  const handleChange = useCallback(changes => {
      // @ts-ignore
    const values: string[] = value;
    const selectedItemValue = changes?.selectedItem?.value;
      const isExist = values?.includes(selectedItemValue);
      let data = [...values, selectedItemValue];
      if (isExist) {
        data = values?.filter((item) => item !== selectedItemValue) || [];
      }
      // @ts-ignore
      onChange(data);
    },
    [onChange]
  );

  // @ts-ignore
  const handleClear = () => onChange([]);
  // @ts-ignore
  const handleSelectAll = () => onChange(options.map(option => option?.value));

  const {
    isOpen,
    openMenu,
    closeMenu,
    getMenuProps,
    getItemProps,
    getInputProps,
    getComboboxProps,
  } = useCombobox({
    labelId: `${id}-label`,
    menuId: `${id}-menu`,
    items: options,
    // @ts-ignore
    selectedItem,
    onSelectedItemChange: handleChange,
    // @ts-ignore
    itemToString(item) {
      return item && displayFn ? displayFn(item) : '';
    },
    stateReducer: (_state, actionAndChanges) => {
      const { changes } = actionAndChanges;
      switch (actionAndChanges?.type) {
        case useCombobox.stateChangeTypes.InputKeyDownEnter:
        case useCombobox.stateChangeTypes.ItemClick: {
          return {
            ...changes,
            isOpen: !!changes.selectedItem,
          };
        }
        default:
          return changes;
      }
    },
  });

  const optionsRenderer = useMemo(
    () => options.map((item, index) => {
      const values = value;
      // @ts-ignore
      const isSelectedItem = values.includes(item?.value);
      return (
        <ListItem
          className={`
            multiSelect
            ${isSelectedItem ? 'selectedItem' : ''} 
            ${isMobile ? 'isMobile' : ''} 
            ${isMobileIOS ? 'isMobileIOS' : ''}
          `}
          key={item?.value}
          {...getItemProps({item, index})}
        >
          {!isMobileIOS && (
            <CheckboxWrapper><Checkbox checked={selectedItem.includes(item)}/></CheckboxWrapper>
          )}
          <span>{ displayFn(item) || '' }</span>
          {isMobileIOS && (
            <>
              <IconWrapper className={`multiSelect ${isSelectedItem ? 'selectedItem' : ''} ${isMobileIOS ? 'isMobileIOS' : ''}`}>
                {selectedItem.includes(item) && (
                  <Icon name="check" />
                )}
              </IconWrapper>
              <LineBottom/>
            </>
          )}
        </ListItem>
      )
    }),
    [value, options, getItemProps, isOpen, isMobile]
  );

  return (
    <Container ref={refContainer}>
      <DropdownWrapper {...getComboboxProps()} className={`${isOpen ? 'isOpen' : ''}`}>
        <Input
          {...attrs}
          {...getInputProps({
            ref: (event) => {
              (ref.current = event);
            },
            refKey: 'inputRef',
            disabled,
            onFocus: () => !isOpen && openMenu(),
            onClick: () => !isOpen && openMenu(),
          })}
          icon={<Icon name="arrow-down-fill" className="cursorPointer" onClick={() => isOpen ? closeMenu() : openMenu()} />}
          label={label}
          placeholder={placeholder}
          value={`Selected (${value?.length}) ${label}`}
          type="dropdown"
          longParagraph={false}
        />
      </DropdownWrapper>
      <ListBox
        {...getMenuProps()}
        isOpen={isOpen}
        className={` multiSelect ${!isOpen ? 'hidden' : ''} ${assitiveText ? 'assitiveText' : ''}  ${isMobile ? 'isMobile' : ''} ${isMobileIOS ? 'isMobileIOS' : ''}`}
        minWidth={refContainer?.current?.clientWidth}
        heightType={type}
      >
        {isOpen && (
          <>
            {isMobileIOS && <BackgroundListBox />}
            {isMobile && (
              <ListBoxMobileHeader className={`${isMobileIOS ? 'isMobileIOS' : ''}`}>
                {!isMobileIOS && (
                  <ArrowBackButton
                    aria-label="Exit dropdown"
                    onClick={closeMenu}
                    type="button"
                  >
                    <Icon name="arrow-left" />
                  </ArrowBackButton>
                )}
                <LabelTitle className={`${isMobileIOS ? 'isMobileIOS' : ''}`}>{label}</LabelTitle>
                {isMobileIOS && (
                  <ButtonReset onClick={() => handleClear()}>Reset</ButtonReset>
                )}
              </ListBoxMobileHeader>
            )}
            <ListBoxListContainer
              ref={listBoxDropdownRef}
              heightType={type}
              className={`${isMobile ? 'isMobile' : ''} ${isMobileIOS ? 'isMobileIOS' : ''}`}
            >
              {optionsRenderer}
            </ListBoxListContainer>
            <ButtonFooter className={cx(isMobileIOS && 'isMobileIOS')}>
              <ItemButton className={cx(isMobileIOS && 'hidden')} onClick={() => handleClear()}>CLEAR</ItemButton>
              <LineButton className={cx(isMobileIOS && 'hidden')} />
              <ItemButton className={cx(isMobileIOS && 'hidden')} onClick={() => handleSelectAll()}>SELECT ALL</ItemButton>
              <ItemButton className={cx('apply-button', isMobileIOS ? 'show' : 'hidden')} onClick={() => closeMenu()}>Apply</ItemButton>
            </ButtonFooter>
          </>
        )}
      </ListBox>
    </Container>
  );
};
