import React, {useCallback, useMemo} from 'react';
import { useCombobox } from 'downshift';
import { isMobile, isIOS } from 'react-device-detect';

import { noop } from '../../utils';
import { Input } from '../Input';
import { Icon } from '../../Icon';

import {
  Container,
  DropdownWrapper,
  ListBox,
  ListBoxMobileHeader,
  ArrowBackButton,
  ListBoxListContainer,
  ListItem,
  IconWrapper,
  BackgroundListBox,
  LabelTitle,
  LineBottom,
} from './styles';
import { DropdownProps } from "./index";

export const DropdownSingle = ({
  className,
  id,
  name,
  label,
  value,
  onClick,
  onChange = noop,
  onBlur,
  onFocus,
  displayFn = (item) => item?.label,
  disabled,
  required,
  status ='default',
  inputRef,
  options = [],
  type = 'short',
  size = 'medium',
  placeholder,
  assitiveText,
  ...props
  }: DropdownProps) => {
  const defaultDropdownRef = React.useRef(null);
  const ref = inputRef || defaultDropdownRef;
  const refContainer = React.useRef<HTMLDivElement>(null);
  const listBoxDropdownRef = React.useRef(null);
  const [highlightedIndex, setHighlightedIndex] = React.useState(-1);
  const isMobileIOS = isMobile && isIOS;
  /**
   * @type {{[key: string]: any }}
   */
  const attrs = {
    onMouseDown: onClick,
    onBlur,
    onFocus,
    value,
    status,
    size,
    disabled,
    required,
    assitiveText,
    ...props,
  };

  const selectedItem = useMemo(
    () => options.find((option) => option.value === value) || null,
    [value, options]
  );

  const handleChange = useCallback(changes => {
      onChange(changes?.selectedItem?.value);
    },
    [onChange]
  );

  const handleHighlightedIndexChange = useCallback(changes => {
    setHighlightedIndex(changes.highlightedIndex);
  }, []);

  const {
    isOpen,
    openMenu,
    closeMenu,
    getMenuProps,
    getItemProps,
    getInputProps,
    getComboboxProps,
  } = useCombobox({
    labelId: `${id}-label`,
    menuId: `${id}-menu`,
    items: options,
    selectedItem,
    onSelectedItemChange: handleChange,
    highlightedIndex,
    onHighlightedIndexChange: handleHighlightedIndexChange,
    itemToString: (item) => {
      return (item ? displayFn(item) : '') as string;
    },
  });

  const optionsRenderer = useMemo(
    () => options.map((item, index) => (
      <ListItem
        aria-selected={highlightedIndex === index}
        className={`
          ${highlightedIndex === index ? 'highlighted' : ''} 
          ${selectedItem === item ? 'selectedItem' : ''} 
          ${isMobile ? 'isMobile' : ''} 
          ${isMobileIOS ? 'isMobileIOS' : ''}
        `}
        key={item.value}
        {...getItemProps({item, index})}
      >
        <span>{ displayFn(item) || '' }</span>
        <IconWrapper className={`${selectedItem === item ? 'selectedItem' : ''} ${isMobileIOS ? 'isMobileIOS' : ''}`}>
          {selectedItem === item && (
            <Icon name="check" />
          )}
        </IconWrapper>
        {isMobileIOS && (
          <LineBottom />
        )}
      </ListItem>
    )),
    [options, getItemProps, highlightedIndex, isOpen, isMobile]
  );

  return (
    <Container ref={refContainer}>
      <DropdownWrapper {...getComboboxProps()} className={`${isOpen ? 'isOpen' : ''}`}>
        <Input
          {...attrs}
          {...getInputProps({
            ref: (event) => {
              (ref.current = event);
            },
            refKey: 'inputRef',
            disabled,
            onFocus: () => !isOpen && openMenu(),
            onClick: () => !isOpen && openMenu(),
          })}
          icon={<Icon name="arrow-down-fill" className="cursorPointer" onClick={() => isOpen ? closeMenu() : openMenu()} />}
          label={label}
          placeholder={placeholder}
          value={displayFn(selectedItem)}
          type="dropdown"
          longParagraph={false}
        />
      </DropdownWrapper>
      <ListBox
        {...getMenuProps()}
        isOpen={isOpen}
        className={`
          ${!isOpen ? 'hidden' : ''} 
          ${assitiveText ? 'assitiveText' : ''} 
          ${isMobile ? 'isMobile' : ''} 
          ${isMobileIOS ? 'isMobileIOS' : ''}
         `}
        minWidth={refContainer?.current?.clientWidth}
        heightType={type}
      >
        {isOpen && (
         <>
           {isMobileIOS && <BackgroundListBox />}
           {isMobile && (
             <ListBoxMobileHeader className={`${isMobileIOS ? 'isMobileIOS' : ''}`}>
               {!isMobileIOS && (
                 <ArrowBackButton
                   aria-label="Exit dropdown"
                   onClick={closeMenu}
                   type="button"
                 >
                   <Icon name="arrow-left" />
                 </ArrowBackButton>
               )}
               <LabelTitle className={`${isMobileIOS ? 'isMobileIOS' : ''}`}>{label}</LabelTitle>
             </ListBoxMobileHeader>
           )}
           <ListBoxListContainer
             ref={listBoxDropdownRef}
             heightType={type}
             className={`${isMobile ? 'isMobile' : ''} ${isMobileIOS ? 'isMobileIOS' : ''}`}
           >
             {optionsRenderer}
           </ListBoxListContainer>
         </>
        )}
      </ListBox>
    </Container>
  );
};
