import React, { useState } from 'react';

import theme from '../../theme';
import { noop } from '../../utils';
import { Icon, IconName } from '../../Icon';

import {
  Container,
  InputWrapper,
  ParagraphWrapper,
  ErrorIcon,
  PrefixLabel,
  SuffixLabel,
  InputContainer,
  SubLabel,
  InputStyle,
  TextareaStyle,
  SuffixWrapper,
  IconWrapper,
} from './styles';

const { sizes } = theme;

export type InputProps = {
  /**
   * Input name
   */
  name?: string,
  /**
   * Input label
   */
  label?: string,
  /**
   * The input content value
   */
  value?: string | number,
  /**
   * Callback when user blur
   */
  onBlur?: () => void
  /**
   * Callback when user focus
   */
  onFocus?: () => void
  /**
   * Disabled input
   */
  disabled?: boolean,
  /**
   * Whether this input is required or not
   */
  required?: boolean,
  /**
   * Input status (useful when implemented with form validation)
   */
  status?: 'error' | 'default',
  /**
   * Promp a assitiveText below input (useful when implemented with form validation)
   */
  assitiveText?: string,
  /**
   * Maximum number of characters allowed. 0, null and undefined mean no limitation
   */
  characterLimit?: number,
  longParagraph?: boolean,
  size?: 'medium' |'small',
  icon?: IconName | React.ReactNode,
  prefix?: string,
  suffix?: string,
  placeholder?: string,
} & React.HTMLAttributes<HTMLInputElement | HTMLTextAreaElement>;

export const Input = (
  {
    id,
    name,
    label,
    value = '',
    onBlur = noop,
    onFocus = noop,
    disabled,
    required,
    status = 'default',
    assitiveText,
    characterLimit = 0,
    longParagraph = false,
    size = 'medium',
    icon,
    prefix,
    suffix,
    placeholder,
    ...props
  }: InputProps) => {

  const [prefixWidth, setPrefixWidth] = useState<number>(0);
  const [isFocused, setIsFocused] = useState(false);
  const [isWithError, setIsWithError] = useState(status === 'error');

  const isCharacterLimitError = characterLimit > 0 && value.toString().length > characterLimit;

  const sizeClass = size === 'small' ? 'small' : '';
  const hasValueClass = value ? 'hasValue' : '';
  const noValueClass = !value ? 'noValue' : '';
  const noLabelClass = !label ? 'noLabel' : '';
  const requiredClass = required ? 'required' : '';
  const isFocusedClass = isFocused ? 'focus' : '';
  const disabledClass = disabled ? 'disabled' : '';
  const isWithErrorClass = isWithError ? 'error' : '';
  const isCharacterLimitErrorClass = isCharacterLimitError ? 'isCharacterLimitError' : '';
  const hasIconClass = icon ? 'hasIcon' : '';
  const longParagraphClass = longParagraph ? 'longParagraph' : '';

  const containerWidth = sizes.full || 'initial';

  const className = `${sizeClass} ${hasValueClass} ${noLabelClass} ${requiredClass} ${isFocusedClass}`;
  const wrapperClassname = `${disabledClass} ${isWithErrorClass} ${isCharacterLimitErrorClass} ${sizeClass}
  ${hasIconClass} ${longParagraphClass} ${noValueClass} ${isFocusedClass}`;
  const attrs = {
    className,
    onFocus,
    value,
    disabled,
    ...props,
  };
  const handleBlur = (event) => {
    if (!isWithError) {
      setIsWithError(isCharacterLimitError);
    }
    onBlur(event);
    setIsFocused(false);
  };

  const handleFocus = (event) => {
    setIsWithError(status === 'error');
    onFocus(event);
    setIsFocused(true);
  };


  return (
    <Container containerWidth={containerWidth}>
      <InputWrapper className={wrapperClassname}>
        {prefix &&
          <PrefixLabel ref={(prefixRef) => setPrefixWidth(prefixRef?.clientWidth || 0)}>
            {prefix}
          </PrefixLabel>}
        <InputContainer>
          {longParagraph ?
            <TextareaStyle
              {...attrs}
              onBlur={(e) => handleBlur(e)}
              onFocus={(e) => handleFocus(e)}
              placeholder={isFocused ? placeholder : ''}
            /> :
            <InputStyle
              {...attrs}
              onBlur={(e) => handleBlur(e)}
              onFocus={(e) => handleFocus(e)}
              placeholder={isFocused ? placeholder : ''}
            />
          }
          {label &&
            <SubLabel
              className={`${required} ${sizeClass} ${isFocusedClass} ${hasValueClass} ${isWithErrorClass}`}
              prefixWidth={prefixWidth}
              htmlFor={id}
            >
              {label}
            </SubLabel>
          }
        </InputContainer>
        <SuffixWrapper longParagraph={longParagraph}>
          {status === 'error' && (
            <ErrorIcon>
              <Icon name="alert-circle" />
            </ErrorIcon>
          )}
          {icon && (
            <IconWrapper className="icon">
              {typeof icon === "string"  ? (
                <Icon name={icon} />
              ) : icon}
            </IconWrapper>
          )}
          {suffix && (
            <SuffixLabel className="ml-2 text-right">
              {suffix}
            </SuffixLabel>
          )}
        </SuffixWrapper>
      </InputWrapper>
      <ParagraphWrapper className={wrapperClassname}>
        <span className="assitiveText">{assitiveText}</span>
        <span className="characterLimit">{characterLimit > 0 && (<>{value.toString().length}/{characterLimit} characters</>)}</span>
      </ParagraphWrapper>
    </Container>
  );
};
