import React, {useEffect, useRef, useState} from 'react';
import { isMobile, isIOS } from 'react-device-detect';

import { Button, cx, noop, Icon, createUniversalPortal } from '../../index';

import {
  Modal,
  Backdrop,
  StyledPopup,
  StyledHeader,
  ContextWrapper,
  Image,
  ChildrenWrapper,
  ButtonWrapper,
} from './styles';

/**
 * Popup informs users about critical information or require decisions.
 */
export type PopupProps = {
  /**
   * Popup max width
   */
  maxWidth?: string,
  /**
   * Popup image
   */
  image?: any,
  /**
   * Popup title
   */
  title?: string,
  /**
   * Popup className (can be used to add more styles to mainIcon by targeting `main-icon` class in case of using a custom string)
   */
  className?: string,
  /**
   * Popup content
   */
  children?: any,
  /**
   * Popup button label
   */
  btnLabel1?: string | React.ReactNode,
  btnLabel2?: string | React.ReactNode,
  btnLabel3?: string | React.ReactNode,
  /**
   * Whether this Popup is open or not
   */
  open?: boolean,
  /**
   * Applies to mobile view only, Button Group Position
   */
  isMobileVertical?: boolean,
  /**
   * Applies to mobile view only, Close button to the left of the header
   * With ISO always displayed on the left
   */
  isCloseButtonLeft?: boolean,
  /**
   * Callback when close icon is clicked. Normally, it is used to update `open` prop to close the popup.
   */
  onClose?: React.MouseEventHandler,
  /**
   * Callback when popup main button is clicked
   */
  onButtonClick1?: React.MouseEventHandler,
  onButtonClick2?: React.MouseEventHandler,
  onButtonClick3?: React.MouseEventHandler,
};

export const Popup = (
  {
    maxWidth,
    image = null,
    title = '',
    className,
    children,
    btnLabel1 = 'confirm',
    btnLabel2 = 'cancel',
    btnLabel3 = '',
    open = false,
    isMobileVertical = false,
    isCloseButtonLeft = false,
    onClose = noop,
    onButtonClick1 = noop,
    onButtonClick2 = noop,
    onButtonClick3 = noop,
    ...props
  }: PopupProps) => {
  const refPopup = useRef<HTMLDivElement>(null);
  const [hasScrollbar, setHasScrollbar] = useState(false);
  const [isSticky, setIsSticky] = useState(false);
  const childrenWrapperClasses = cx(
    (typeof children === 'string' || typeof children === 'number') && 'is-single-string',
    isMobile && 'isMobile',
  );

  const handleSticky = () => {
    const offsetTop = refPopup.current?.offsetTop || 0;
    const scrollTop = document.querySelector('.popupContext')?.getClientRects()?.[0]?.top || 0;
    const headerHeight = document.querySelector('.popupHeader')?.getClientRects()?.[0]?.height || 0;
    setIsSticky(scrollTop - (offsetTop + headerHeight) < -2);
  };

  useEffect(() => {
    if (refPopup.current !== null) {
      const isScrollbar = refPopup.current.scrollHeight > refPopup.current.clientHeight;
      setHasScrollbar(isScrollbar);
      if (open) {
        refPopup.current.addEventListener('scroll', handleSticky);
      } else {
        refPopup.current.removeEventListener('scroll', handleSticky);
      }
    }
  }, [open]);

  return (
    <div>
      {open &&
        createUniversalPortal(
          <Modal className={cx(isMobile && 'isMobile')}>
            <Backdrop />
            <StyledPopup maxWidth={maxWidth} {...props} ref={refPopup} className={cx(className, isMobile && 'isMobile', isIOS && 'isIOS')}>
              <StyledHeader className={cx('popupHeader', isSticky && 'isSticky', isMobile && 'isMobile', isIOS && 'isIOS', isCloseButtonLeft && 'isCloseButtonLeft')}>
                {title && (<div className="title">{title}</div>)}
                <button className="closeButton" type="button" onClick={onClose}>
                  <Icon name="close" />
                </button>
              </StyledHeader>
              <ContextWrapper className={cx('popupContext', image && 'hasImage', isMobile && 'isMobile', isIOS && 'isIOS')}>
                {image && (
                  typeof image === 'string' ?
                    <Image className={cx('image', isMobile && 'isMobile')} src={image} alt="image" /> :
                    image
                )}
                <ChildrenWrapper className={childrenWrapperClasses}>
                  {children}
                </ChildrenWrapper>
              </ContextWrapper>
              <ButtonWrapper className={cx(isMobile && 'isMobile', (isMobileVertical && isMobile) && 'isMobileVertical', isIOS && 'isIOS', hasScrollbar && 'hasScrollbar')}>
                {btnLabel1 && (
                  typeof btnLabel1 === "string" ? (
                    <Button styles="btn-pri-low" className="buttonAction1" onClick={onButtonClick1}>
                      {btnLabel1}
                    </Button>
                    ): btnLabel1
                )}
                {btnLabel2 && (
                  typeof btnLabel2 === "string" ? (
                    <Button styles="btn-net-low" className="buttonAction2" onClick={onButtonClick2}>
                      {btnLabel2}
                    </Button>
                  ): btnLabel2
                )}
                {btnLabel3 && (
                  typeof btnLabel3 === "string" ? (
                    <Button styles="btn-net-low" className="buttonAction3" onClick={onButtonClick3}>
                      {btnLabel3}
                    </Button>
                  ): btnLabel3
                )}
              </ButtonWrapper>
            </StyledPopup>
          </Modal>
        )}
    </div>
  );
};
