import React, { useState, useEffect } from 'react';
import styled from "styled-components";

import { Button, Dialog, Input } from '../../components';

const dialogStories = {
  title: 'Components/Dialog',
  component: Dialog,
  parameters: {
    docs: {
      description: {
        component: `Mudah UI Dialog component.

\`🧪 Beta\` [\`🎨 Figma Specs\`](https://www.figma.com/file/GKZuT2KxQpY4rty2hhGLE3/Mudah-Design-System?node-id=1061%3A21813)
`,
      },
    },
  },
  argTypes: {
    title: {
      defaultValue: 'Dialog title',
    },
    image: {
      defaultValue: '',
    },
    isLargeSize: {
      defaultValue: false,
    },
    children: {
      defaultValue:
        'Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.',
      control: {
        type: 'text',
      },
    },
    open: {},
    className: { control: null },
    btnLabel1: {
      defaultValue: 'confirm',
    },
    btnLabel2: {
      defaultValue: 'cancel',
    },
    btnLabel3: {
      defaultValue: '',
    },
    isMobileVertical: {
      defaultValue: false,
    },
  },
};

export default dialogStories;

const onMainBtnClick = () => {
  alert('Button clicked.');
};

export const Overview = (args) => {
  const [open, setOpen] = useState(false);
  const toggleModel = () => {
    setOpen(!open);
  };
  useEffect(() => {
    setOpen(args.open);
  }, [args.open]);
  return (
    <>
      <Button onClick={toggleModel}>Open Dialog</Button>
      <Dialog
        {...args}
        open={open}
        onClose={toggleModel}
        onButtonClick1={onMainBtnClick}
        onButtonClick2={() => setOpen(false)}
      >
        Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.
      </Dialog>
    </>
  );
};

export const NoTitle = () => {
  const [open, setOpen] = useState(false);
  const toggleModel = () => {
    setOpen(!open);
  };

  return (
    <>
      <Button onClick={toggleModel}>Open Dialog</Button>
      <Dialog
        open={open}
        onClose={toggleModel}
        onButtonClick1={onMainBtnClick}
        onButtonClick2={() => setOpen(false)}
      >
        Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit?
      </Dialog>
    </>
  );
};

export const WithTitle = () => {
  const [open, setOpen] = useState(false);
  const toggleModel = () => {
    setOpen(!open);
  };

  return (
    <>
      <Button onClick={toggleModel}>Open Dialog</Button>
      <Dialog
        open={open}
        onClose={toggleModel}
        onButtonClick1={onMainBtnClick}
        title="Title Dialog"
        onButtonClick2={() => setOpen(false)}
      >
        Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit?
      </Dialog>
    </>
  );
};

export const WithImage = () => {
  const [open, setOpen] = useState(false);
  const toggleModel = () => {
    setOpen(!open);
  };

  return (
    <>
      <Button onClick={toggleModel}>Open Dialog</Button>
      <Dialog
        open={open}
        onClose={toggleModel}
        title="You can also replace the image"
        image="https://www.simplilearn.com/ice9/free_resources_article_thumb/what_is_image_Processing.jpg"
        onButtonClick1={onMainBtnClick}
        onButtonClick2={() => setOpen(false)}
      >
        Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit,
        sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
        Ut enim ad minim veniam.
      </Dialog>
    </>
  );
};

export const WithForm = () => {
  const [open, setOpen] = useState(false);
  const [value, setValue] = useState('');
  const toggleModel = () => {
    setOpen(!open);
  };

  return (
    <>
      <Button onClick={toggleModel}>Open Dialog</Button>
      <Dialog
        open={open}
        onClose={toggleModel}
        title="Save this search"
        onButtonClick1={onMainBtnClick}
        onButtonClick2={() => setOpen(false)}
      >
        <Input value={value} label="Name you search" onChange={e => setValue(e.currentTarget.value)} />
      </Dialog>
    </>
  );
};

export const LargeSize = () => {
  const Wrapper = styled.div`
    margin-bottom: 1rem;
  `;
  const [open, setOpen] = useState(false);
  const toggleModel = () => {
    setOpen(!open);
  };

  return (
    <>
      <Button onClick={toggleModel}>Open Dialog</Button>
      <Dialog
        open={open}
        isLargeSize
        onClose={toggleModel}
        title="Large Dialog"
        btnLabel1="confirm"
        btnLabel2="cancel"
        onButtonClick1={onMainBtnClick}
        onButtonClick2={() => setOpen(false)}
      >
        <Wrapper>
          A dialog is a type of modal window that appears in front of app
          content to provide critical information or ask for a decision. Dialogs
          disable all app functionality when they appear, and remain on screen
          until confirmed, dismissed, or a required action has been taken.
        </Wrapper>
        <Wrapper>
          Dialogs are purpospfully interruptive, so they should be used sparingly.
        </Wrapper>
        <Wrapper>
          A dialog is a type of modal window. Access to the rest of the UI is
          disabled until the modal is addressed. All modal surfaces are
          interruptive by design - their purpose is to have the user focus on
          content on a surface that appears in front of all other surfaces
        </Wrapper>
        <Wrapper>
          To express that the rest of the app is inaccessible, and to focus
          attention on the dialog, surfaces behind the dialog are scrimmed. A
          scrim is a temporary treatment that can be applied to Material
        </Wrapper>
      </Dialog>
    </>
  );
};

export const Variants = () => {
  const WrapperDialog = styled.div`
    .buttonAction1 {
      color: #FFFFFF;
      background-color: #E21E30;
      border-color: #E21E30;

      &:hover {
        color: #FFFFFF;
        background-color: #FF3638;
        border-color: #FF3638;
      }

      &:active {
        color: #FFFFFF;
        background-color: #9E0017;
        border-color: #9E0017;
      }
    }
  `;

  const Wrapper = styled.div`
    margin-bottom: 1rem;
  `;
  const [open, setOpen] = useState(false);
  const [value, setValue] = useState('');
  const toggleModel = () => {
    setOpen(!open);
  };

  return (
    <WrapperDialog>
      <Button color="secondary" onClick={toggleModel}>Open Dialog</Button>
      <Dialog
        isLargeSize
        isMobileVertical
        open={open}
        onClose={toggleModel}
        title="Variant Dialog"
        btnLabel1="Save"
        btnLabel2="Action 2"
        btnLabel3="Action 3"
        image={
        <div>
          <img
            width="100%"
            src="https://www.simplilearn.com/ice9/free_resources_article_thumb/what_is_image_Processing.jpg"
            alt=""
          />
        </div>
        }
        onButtonClick1={onMainBtnClick}
        onButtonClick2={() => setOpen(false)}
        onButtonClick3={() => setOpen(false)}
      >
        <Wrapper>
          Lorem ipsum dolor sit amet, consectetur adipiscing elit?
        </Wrapper>
        <Input value={value} label="Name you search" onChange={e => setValue(e.currentTarget.value)} />
      </Dialog>
    </WrapperDialog>
  );
};
