import React, { useState } from 'react';
import styled from 'styled-components';

import { Dropdown } from '../../index';

const WrapperDropdown = styled.div`
  display: flex;
  flex-wrap: wrap;
`;

const Col = styled.div<{ paddingBottom?: string;  maxWidth?: string }>`
  width: 100%;
  margin: 1rem;
  padding-bottom: ${({paddingBottom}) => paddingBottom || 0};
  max-width: ${({maxWidth}) => maxWidth || '25rem'};
`;

const defaultDropdown = {
  title: 'Components/Dropdown',
  component: Dropdown,
  parameters: {
    docs: {
      description: {
        component: `Dropdown component that wraps around HTML Select element.

\`🧪 Beta\` [\`🎨 Figma Specs\`](https://www.figma.com/file/GKZuT2KxQpY4rty2hhGLE3/Mudah-Design-System?node-id=271%3A7585)
`,
      },
    },
  },
  argTypes: {
    options: {
      defaultValue: [
        {
          label: 'Item list 1',
          value: '1',
        },
        {
          label: 'Item list 2',
          value: '2',
        },
        {
          label: 'Item list 3',
          value: '3',
        },
        {
          label: 'Item list 4',
          value: '4',
        },
        {
          label: 'Item list 5',
          value: '5',
        },
        {
          label: 'Item list 6',
          value: '6',
        },
        {
          label: 'Item list 7',
          value: '7',
        },
        {
          label: 'Item list 8',
          value: '8',
        },
        {
          label: 'Item list 9',
          value: '9',
        },
        {
          label: 'Item list 10',
          value: '10',
        },
        {
          label: 'Item list 11',
          value: '11',
        },
        {
          label: 'Item list 12',
          value: '12',
        },
      ],
    },
    label: {
      defaultValue: 'Select value',
    },
    disabled: {},
    required: {},
    status: {},
    id: { control: null },
    name: { control: null },
    value: { control: null },
    onChange: { control: null },
    onBlur: { control: null },
    onFocus: { control: null },
    inputRef: { control: null },
  },
};

export default defaultDropdown;

// top-most story will have the props breakdown
export const Overview = (args) => {
  const [value, setValue] = useState('');
  return (
    <WrapperDropdown>
      <Col paddingBottom="32rem">
        <Dropdown
          id="overview"
          name="overview"
          {...args}
          value={value}
          onChange={e => setValue(e)}
        />
      </Col>
      <Col>
        <p>Value: {value || 'Please select an option.'}</p>
      </Col>
    </WrapperDropdown>
  );
};


export const SmalSize = () => {
  const [value, setValue] = useState('');
  return (
    <WrapperDropdown>
      <Col paddingBottom="10vh">
        <Dropdown
          value={value}
          onChange={e => setValue(e)}
          label="Select option ..."
          size="small"
          options={[
            { value: '01', label: 'Item 01' },
            { value: '02', label: 'Item 02' },
          ]}
        />
      </Col>
      <Col>
        <p>Value: {value || 'Please select an option.'}</p>
      </Col>
    </WrapperDropdown>
  );
};

SmalSize.parameters = {
  docs: {
    description: {
      story: 'Set `size="small"`',
    },
  },
};

export const TypeDropdown = (args) => {

  const [value, setValue] = useState('');
  return (
    <WrapperDropdown>
      <Col paddingBottom="32rem" maxWidth="17rem">
        <Dropdown
          {...args}
          value={value}
          type="short"
          onChange={e => setValue(e)}
          label="Dropdown short"
        />
      </Col>
      <Col paddingBottom="32rem" maxWidth="17rem">
        <Dropdown
          {...args}
          value={value}
          type="tall"
          onChange={e => setValue(e)}
          label="Dropdown tall"
        />
      </Col>
      <Col paddingBottom="32rem" maxWidth="17rem">
        <Dropdown
          {...args}
          value={value}
          type="scroll"
          onChange={e => setValue(e)}
          label="Dropdown scroll"
        />
      </Col>
    </WrapperDropdown>
  );
};

TypeDropdown.parameters = {
  docs: {
    description: {
      story: 'Set `type=["short", "tall", "scroll"]`',
    },
  },
};

export const MultiSelect = () => {
  const [value, setValue] = useState([]);
  return (
    <WrapperDropdown>
      <Col paddingBottom="10vh">
        <Dropdown
          value={value}
          onChange={e => setValue(e)}
          label="Select option ..."
          multiSelect
          assitiveText="Error message here"
          options={[
            { value: '01', label: 'Item 01' },
            { value: '02', label: 'Item 02' },
          ]}
        />
      </Col>
      <Col>
        <p>Value: {value.join(', ') || 'Please select an option.'}</p>
      </Col>
    </WrapperDropdown>
  );
};

MultiSelect.parameters = {
  docs: {
    description: {
      story: 'Set `multiSelect="true"`',
    },
  },
};

export const WithError = () => {
  const [value, setValue] = useState('');
  return (
    <WrapperDropdown>
      <Col paddingBottom="10vh">
        <Dropdown
          value={value}
          onChange={e => setValue(e)}
          label="Select option ..."
          status="error"
          assitiveText="Error message here"
          options={[
            { value: '01', label: 'Item 01' },
            { value: '02', label: 'Item 02' },
          ]}
        />
      </Col>
      <Col>
        <p>Value: {value || 'Please select an option.'}</p>
      </Col>
    </WrapperDropdown>
  );
};

WithError.parameters = {
  docs: {
    description: {
      story: 'Set `status="error"` will let Input has red borders and assitive Text, indicate error status.',
    },
  },
};

export const Disabled = () => {
  const [value, setValue] = useState('');
  return (
    <WrapperDropdown>
      <Col paddingBottom="10vh">
        <Dropdown
          value={value}
          onChange={e => setValue(e)}
          label="Select option ..."
          disabled
          options={[
            { value: '01', label: 'Item 01' },
            { value: '02', label: 'Item 02' },
          ]}
        />
      </Col>
      <Col>
        <p>Value: {value || 'Please select an option.'}</p>
      </Col>
    </WrapperDropdown>
  );
};

Disabled.parameters = {
  docs: {
    description: {
      story: 'Set `disabled="true"`',
    },
  },
};

export const WiderSizeInput = () => {
  const [value, setValue] = useState('');
  return (
    <WrapperDropdown>
      <Col paddingBottom="5rem" maxWidth="14rem">
        <Dropdown
          value={value}
          onChange={e => setValue(e)}
          label="Select option ..."
          options={[
            { value: '01', label: 'Red Delicious XL Apple' },
            { value: '02', label: 'Expensive Japanese Melon' },
          ]}
        />
      </Col>
      <Col>
        <p>Value: {value || 'Please select an option.'}</p>
      </Col>
    </WrapperDropdown>
  );
};

WiderSizeInput.parameters = {
  docs: {
    description: {
      story: 'Dropdown List can have wider size than the dropdown input itself to support longer text list',
    },
  },
};
