const neutrals = {
  black: '#222222',
  darkgray1: '',
  darkgray2: '',
  darkgray3: '#777777',
  darkgray4: '',
  gray1: '#9B9B9B',
  gray2: '#CACACA',
  gray3: '#E8E8E8',
  gray4: '#F4F4F4',
  gray5: '#F8F8F8',
  white: '#FFFFFF',
};
/**
 * Map numeric values to CSS px values
 * @param {*} v
 */
const px = (v: any) => `${v}px`;

/**
 * @breakpoints
 *
 * When used with `sx` helper, 0 index means for all viewports (mobile first):
 *
 * ```
 * sx({
 *   // applies font size small to all viewport widths,
 *   // font size medium above the first breakpoint,
 *   // font size large above the next breakpoint
 *   fontSize: [ 'small', 'medium', 'large' ]
 * })
 * ```
 */
const breakpoints = ['576px', '768px', '992px', '1200px', '1400px'];
// index in sx:         1,       2,       3,       4,        5  (not a mistake, 0 is smallest viewport)

/**
 * @mediaQueries
 *
 * Example:
 * @media ${theme.mediaQueries.tablet} {
 *   font-size: ${theme.fontSize.small}
 * }
 */
const mediaQueries = {
  tablet: `screen and (min-width: ${breakpoints[1]})`,
  desktop: `screen and (min-width: ${breakpoints[2]})`,
};

/**
 * @sizes
 */
// index:              0,  1,  2,  3,  4,  5,  6,  7,  8,   9,
const iconSizeScale = [16, 20, 22, 24, 32, 40, 50, 75, 100, 105].map(px);

const sizes = {
  vW: '100vw',
  vH: '100vh',
  quarter: '25%',
  third: '33.33%',
  half: '50%',
  twoThird: '66.66%',
  threeQuarter: '75%',
  full: '100%',
  icons: iconSizeScale,
  [1 / 4]: '25%',
  [1 / 3]: '33.33%',
  [1 / 2]: '50%',
  [2 / 3]: '66.66%',
  [3 / 4]: '75%',
  1: '100%',
};

/**
 * @fonts
 */
const fonts = {
  body: '-apple-system, BlinkMacSystemFont, Open Sans, Roboto, sans-serif',
  heading: 'inherit',
  monospace: 'SFMono-Regular, Consolas, Liberation Mono, Menlo, monospace',
};

/**
 * @lineHeights
 */
// index:            0,   1,   2,   3,   4,   5
const inputHeights = {
  sm: '36px',
  md: '56px',
  xs: '176px',
};

/**
 * @fontWeights
 */
const fontWeights = {
  regular: 400,
  bold: 700,
  body: 400, // regular
  heading: 700, // bold
  normal: 400,
};

const primarys = {
  primary50: '#ffebef',
  primary100: '#FFCDD4',
  primary200: '#F7999D',
  primary300: '#F07176',
  primary400: '#FD4C53',
  primary500: '#FF3638',
  primary600: '#F42B38',
  primary700: '#E21E30',
  primary800: '#D5132A',
  primary900: '#9E0017',
};

const secondarys = {
  secondary50: '#DDEFFD',
  secondary100: '#BBDEFB',
  secondary200: '#90CAF9',
  secondary300: '#64B5F6',
  secondary400: '#42A5F5',
  secondary500: '#2196F3',
  secondary600: '#1E88E5',
  secondary700: '#1976D2',
  secondary800: '#1565C0',
  secondary900: '#0D47A1',
};

const greens = {
  green50: '#E5F4E9',
  green100: '#C0E5C9',
  green200: '#97D3A8',
  green300: '#6BC385',
  green400: '#47B76C',
  green500: '#17AA52',
  green600: '#0a9b49',
  green700: '#00893D',
  green800: '#007832',
  green900: '#00591F',
};

const yellows = {
  yellow50: '#FFF7E1',
  yellow100: '#FEEAB4',
  yellow200: '#FEDD84',
  yellow300: '#FDD153',
  yellow400: '#FCC630',
  yellow500: '#FBBD1C',
  yellow600: '#FBAF17',
  yellow700: '#FA9D16',
  yellow800: '#FA8C15',
  yellow900: '#F86D13',
};

const grays = {
  gray50: '#FAFAFA',
  gray100: '#F5F5F5',
  gray200: '#EEEEEE',
  gray300: '#E0E0E0',
  gray400: '#BDBDBD',
  gray500: '#9E9E9E',
  gray600: '#757575',
  gray700: '#616161',
  gray800: '#424242',
  gray900: '#212121',
};

const surfaces = {
  surface1: '#ffebef',
  surface2: '#E1F6FD',
  surface3: '#E5F4E9',
  surface25: '#FFFFFF',
  surface100: '#F5F5F5',
  surface300: '#E0E0E0',
  surface500: '#9E9E9E',
  surface700: '#616161',
  surface900: '#212121',
};

const error = {
  error50: '#ffebef',
  error900: '#C7001D',
};

const warning = {
  warning50: '#FFF7E1',
  warning800: '#FA8C15',
};

const success = {
  success50: '#E5F4E9',
  success700: '#00893D',
};

const texts = {
  text038: '#00000061',
  text060: '#00000099',
  text087: '#000000DE',
  text025: '#FFFFFF',
  text600: '#1E88E5',
  text900: '#9E0017',
};

const buttons = {
  buttonRed: primarys.primary700,
  buttonBlue: secondarys.secondary600,
};

const semantics = {
  white: '#FFFFFF',
  black: '#000000',
  backgroundIOS: '#34C759',
  grayIOS: 'rgba(242, 242, 242, 0.8)',
  /**
   * Main body text color
   * @type {string}
   */
  text: texts.text087,
  /**
   * De-emphasized / footer text color
   * @type {string}
   */
  textLighter: texts.text060,
  /**
   * Regular hyperlinks color
   * @type {string}
   */
  link: texts.text600,
  /**
   * Primary brand color for links, buttons, etc.
   * @type {string}
   */
  primary: primarys.primary700,
  /**
   * A secondary brand color for alternative styling
   * @type {string}
   */
  secondary: secondarys.secondary600,
  green: greens.green600,
  yellow: yellows.yellow600,
  /**
   * Color for borders
   */
  border: grays.gray500,
  background: grays.gray300,
};

const colors = {
  ...primarys,
  ...secondarys,
  ...neutrals,
  ...greens,
  ...yellows,
  ...grays,
  ...surfaces,
  ...error,
  ...success,
  ...warning,
  ...texts,
  ...semantics,
  ...yellows,
  ...greens,
  ...buttons,
};

/**
 *  * theme.radi
 *
 * border-radius
 */
const radii = {
  /**
   * No border radius
   */
  none: 0,
  /**
   * Used for images, thumbnails
   */
  xs: '2px',
  /**
   * Used for buttons
   */
  sm: '4px',
  /**
   * Unused
   */
  md: '8px',
  /**
   * Unused
   */
  lg: '14px',
  /**
   * Used for c2c home page thumbnails
   */
  xl: '20px',
  /**
   * Used for pill buttons
   *
   * '9999px'
   */
  pill: '9999px',
  /**
   * Used for icons frames
   *
   * '100%'
   */
  circle: '100%',
};

const zIndices = {
  initial: 'auto',
  neutral: 0,
  up: 1,
  down: -1,
  notification: 1900,
  tooltip: 1800,
  modal: 1700,
  dropdown: 1600,
};
/**
 * Whole theme object
 */
export const theme = Object.freeze({
  breakpoints: {
    ...breakpoints,
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px',
    xxl: '1400px',
  },
  mediaQueries,
  sizes,
  fonts,
  fontWeights,
  colors: {
    ...colors,
    line: '#ddd',
  },
  radii,
  inputHeights,
  texts,
  zIndices,
});

export default theme;
